@@ -1,7 +1,7 @@
 /*
  * ion/de/colour.h
  *
- * Copyright (c) Tuomo Valkonen 1999-2004. 
+ * Copyright (c) Tuomo Valkonen 1999-2006. 
  *
  * Ion is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by
@@ -29,8 +29,8 @@ DECLSTRUCT(DEColourGroup){
 };
 
 
-#define DE_BLACK(rootwin) BlackPixel(wglobal.dpy, rootwin->xscr)
-#define DE_WHITE(rootwin) WhitePixel(wglobal.dpy, rootwin->xscr)
+#define DE_BLACK(rootwin) BlackPixel(ioncore_g.dpy, rootwin->xscr)
+#define DE_WHITE(rootwin) WhitePixel(ioncore_g.dpy, rootwin->xscr)
 
 bool de_init_colour_group(WRootWin *rootwin, DEColourGroup *cg);
 bool de_alloc_colour(WRootWin *rootwin, DEColour *ret, const char *name);
