@@ -1,7 +1,7 @@
 /*
  * ion/ioncore/clientwin.c
  *
- * Copyright (c) Tuomo Valkonen 1999-2005. 
+ * Copyright (c) Tuomo Valkonen 1999-2006. 
  *
  * Ion is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by
@@ -39,11 +39,15 @@
 #include "activity.h"
 #include "netwm.h"
 #include "xwindow.h"
+#include "basicpholder.h"
 
 
 static void set_clientwin_state(WClientWin *cwin, int state);
 static bool send_clientmsg(Window win, Atom a, Time stmp);
 
+static void do_gravity(const WRectangle *max_geom, int gravity,
+                       WRectangle *geom);
+
 
 WHook *clientwin_do_manage_alt=NULL;
 WHook *clientwin_mapped_hook=NULL;
@@ -205,7 +209,7 @@ static void clientwin_get_winprops(WClientWin *cwin)
         cwin->flags|=CLIENTWIN_PROP_IGNORE_CFGRQ;
 
     if(extl_table_is_bool_set(tab, "transients_at_top"))
-        cwin->transient_gravity = NorthGravity;
+        cwin->transient_gravity=NorthGravity;
 
     cwin->gravity=get_gravity_winprop(cwin,"gravity");
     cwin->transient_gravity=get_gravity_winprop(cwin,"transient_gravity");
@@ -270,7 +274,7 @@ void clientwin_get_set_name(WClientWin *cwin)
 /* Some standard winprops */
 
 
-bool clientwin_get_switchto(WClientWin *cwin)
+bool clientwin_get_switchto(const WClientWin *cwin)
 {
     bool b;
     
@@ -284,7 +288,7 @@ bool clientwin_get_switchto(WClientWin *cwin)
 }
 
 
-int clientwin_get_transient_mode(WClientWin *cwin)
+int clientwin_get_transient_mode(const WClientWin *cwin)
 {
     char *s;
     int mode=TRANSIENT_MODE_NORMAL;
@@ -345,7 +349,6 @@ static bool clientwin_init(WClientWin *cwin, WWindow *par, Window win,
 
     cwin->last_fp.g=geom;
     cwin->last_fp.mode=REGION_FIT_EXACT;
-    cwin->last_h_rq=geom.h;
 
     cwin->transient_for=None;
     cwin->transient_list=NULL;
@@ -360,7 +363,7 @@ static bool clientwin_init(WClientWin *cwin, WWindow *par, Window win,
     cwin->fs_pholder=NULL;
 
     cwin->gravity=ForgetGravity;
-    cwin->transient_gravity=SouthGravity;
+    cwin->transient_gravity=ForgetGravity;
     
     region_init(&(cwin->region), par, &(cwin->last_fp));
 
@@ -387,7 +390,7 @@ static WClientWin *create_clientwin(WWindow *par, Window win,
 }
 
 
-static bool handle_target_props(WClientWin *cwin, const WManageParams *param)
+static bool handle_target_prop(WClientWin *cwin, const WManageParams *param)
 {
     WRegion *r=NULL;
     char *target_name=NULL;
@@ -404,14 +407,11 @@ static bool handle_target_props(WClientWin *cwin, const WManageParams *param)
         }
     }
     
-    if(!extl_table_is_bool_set(cwin->proptab, "fullscreen"))
-            return FALSE;
-    
-    return clientwin_enter_fullscreen(cwin, param->switchto);
+    return FALSE;
 }
 
 
-WClientWin *clientwin_get_transient_for(WClientWin *cwin)
+WClientWin *clientwin_get_transient_for(const WClientWin *cwin)
 {
     Window tforwin;
     WClientWin *tfor=NULL;
@@ -587,7 +587,7 @@ again:
     
     param.tfor=clientwin_get_transient_for(cwin);
 
-    if(!handle_target_props(cwin, &param)){
+    if(!handle_target_prop(cwin, &param)){
         bool managed;
         void *mrshpm[2];
         
@@ -660,13 +660,27 @@ void clientwin_tfor_changed(WClientWin *cwin)
 
 /*{{{ Add/remove managed */
 
-typedef struct{
-    WClientWin *cwin;
-    WRegion *transient;
-} TransRepar;
+
+static int clientwin_get_transients_gravity(WClientWin *cwin)
+{
+    if(cwin->transient_gravity!=ForgetGravity)
+        return cwin->transient_gravity;
+    if(cwin->last_fp.mode&REGION_FIT_GRAVITY)
+        return cwin->last_fp.gravity;
+    if(cwin->gravity!=ForgetGravity)
+        return cwin->gravity;
+    return SouthGravity;
+}
 
 
-static TransRepar *transient_reparents=NULL;
+static void correct_to_size_hints_of(int *w, int *h, WRegion *reg)
+{
+    XSizeHints hints;
+    
+    region_size_hints(reg, &hints);
+
+    xsizehints_correct(&hints, w, h, FALSE);
+}
 
 
 static WRegion *clientwin_do_attach_transient(WClientWin *cwin, 
@@ -675,56 +689,110 @@ static WRegion *clientwin_do_attach_transient(WClientWin *cwin,
                                               WRegion *thereg)
 {
     WWindow *par=REGION_PARENT(cwin);
-    WRegion *reg;
-    TransRepar tp, *tpold;
-    WFitParams fp;
     Window bottom=None, top=None;
+    WRegion *reg, *mreg;
+    WFitParams fp;
+    WRectangle mg;
+    WFrame *frame=NULL;
 
     if(par==NULL)
         return NULL;
 
-    tp.cwin=cwin;
-    tp.transient=thereg;
-    tpold=transient_reparents;
-    transient_reparents=&tp;
-    
-    fp.mode=REGION_FIT_BOUNDS;
+    fp.mode=REGION_FIT_BOUNDS|REGION_FIT_WHATEVER;
+    fp.gravity=clientwin_get_transients_gravity(cwin);
     fp.g=cwin->last_fp.g;
-    
+
+    if(ioncore_g.framed_transients)
+        frame=create_frame(par, &fp, "frame-transientcontainer");
+
     reg=fn(par, &fp, fnparams);
     
-    transient_reparents=tpold;
-    
-    if(reg==NULL)
+    if(reg==NULL){
+        destroy_obj((Obj*)frame);
         return NULL;
+    }
+
+    if(frame!=NULL){
+        frame->flags|=(FRAME_DEST_EMPTY|
+                       FRAME_TAB_HIDE|
+                       FRAME_SZH_USEMINMAX);
+        mreg=(WRegion*)frame;
+        mplex_managed_geom((WMPlex*)frame, &mg);
+    }else{
+        mreg=reg;
+        mg=REGION_GEOM(reg);
+    }
+    
+    /* border sizes */
+    fp.g.w=REGION_GEOM(mreg).w-mg.w;
+    fp.g.h=REGION_GEOM(mreg).h-mg.h;
+    /* maximum inner size */
+    mg.w=maxof(1, cwin->last_fp.g.w-fp.g.w);
+    mg.h=maxof(1, minof(REGION_GEOM(reg).h, cwin->last_fp.g.h-fp.g.h));
+    /* adjust it to size hints (can only shrink) */
+    correct_to_size_hints_of(&(mg.w), &(mg.h), reg);
+    /* final frame size */
+    fp.g.w+=mg.w;
+    fp.g.h+=mg.h;
+    /* positioning */
+    do_gravity(&(cwin->last_fp.g), fp.gravity, &(fp.g));
+    
+    fp.mode=REGION_FIT_EXACT;
+    
+    region_fitrep((WRegion*)mreg, NULL, &fp);
+    
+    if(frame!=NULL){
+        if(!mplex_attach_simple((WMPlex*)frame, reg, 0)){
+            destroy_obj((Obj*)frame);
+            mreg=reg;
+        }
+    }
 
     region_stacking((WRegion*)cwin, &bottom, &top);
-    region_restack(reg, top, Above);
+    region_restack(mreg, top, Above);
     
-    if(!ptrlist_insert_last(&(cwin->transient_list), reg)){
+    if(!ptrlist_insert_last(&(cwin->transient_list), mreg)){
+        if(frame!=NULL)
+            destroy_obj((Obj*)frame);
+        /* Not necessarily the right thing to do: */
         destroy_obj((Obj*)reg);
         return NULL;
     }
-    region_set_manager(reg, (WRegion*)cwin);
+    region_set_manager(mreg, (WRegion*)cwin);
     
     if(REGION_IS_MAPPED((WRegion*)cwin))
-        region_map(reg);
+        region_map(mreg);
     else
-        region_unmap(reg);
+        region_unmap(mreg);
     
     if(region_may_control_focus((WRegion*)cwin))
-        region_warp(reg);
+        region_set_focus(mreg);
     
     return reg;
 }
 
 
-bool clientwin_attach_transient(WClientWin *cwin, WRegion *transient)
+static WRegion *clientwin_do_attach_transient_simple(WClientWin *cwin, 
+                                                     WRegionAttachHandler *fn,
+                                                     void *fnparams)
 {
-    return (region__attach_reparent((WRegion*)cwin, transient,
+    return clientwin_do_attach_transient(cwin, fn, fnparams, NULL);
+}
+
+
+
+/*EXTL_DOC
+ * Manage \var{reg} as a transient of \var{cwin}.
+ */
+EXTL_EXPORT_MEMBER
+bool clientwin_attach_transient(WClientWin *cwin, WRegion *reg)
+{
+    if(!reg)
+        return FALSE;
+    return (region__attach_reparent((WRegion*)cwin, reg,
                                     ((WRegionDoAttachFn*)
                                      clientwin_do_attach_transient), 
-                                    transient)!=NULL);
+                                    reg)!=NULL);
 }
 
 
@@ -762,17 +830,65 @@ bool clientwin_rescue_clientwins(WClientWin *cwin, WPHolder *ph)
 }
 
 
-bool clientwin_manage_clientwin(WClientWin *cwin, WClientWin *cwin2,
-                                const WManageParams *param, int redir)
+WPHolder *clientwin_prepare_manage(WClientWin *cwin, const WClientWin *cwin2,
+                                   const WManageParams *param, int redir)
 {
     if(redir==MANAGE_REDIR_STRICT_YES)
-        return FALSE;
+        return NULL;
     
     /* Only catch windows with transient mode set to current here. */
     if(clientwin_get_transient_mode(cwin2)!=TRANSIENT_MODE_CURRENT)
-        return FALSE;
+        return NULL;
     
-    return clientwin_attach_transient(cwin, (WRegion*)cwin2);
+    return (WPHolder*)create_basicpholder((WRegion*)cwin,
+                                          ((WRegionDoAttachFnSimple*)
+                                           clientwin_do_attach_transient_simple));
+}
+
+
+static bool clientwin_should_manage_transient(WClientWin *cwin, 
+                                              WClientWin *tfor)
+{
+
+    WRegion *mgr;
+    
+    if(tfor==cwin)
+        return TRUE;
+    
+    mgr=REGION_MANAGER(tfor);
+    
+    if(ioncore_g.framed_transients && OBJ_IS(mgr, WFrame))
+        mgr=REGION_MANAGER(mgr);
+
+    return (mgr==(WRegion*)cwin);
+}
+
+
+WPHolder *clientwin_prepare_manage_transient(WClientWin *cwin, 
+                                             const WClientWin *transient,
+                                             const WManageParams *param,
+                                             int unused)
+{
+    WPHolder *ph=region_prepare_manage_transient_default((WRegion*)cwin,
+                                                         transient,
+                                                         param,
+                                                         unused);
+    
+    if(ph==NULL && clientwin_should_manage_transient(cwin, param->tfor)){
+        ph=(WPHolder*)create_basicpholder((WRegion*)cwin,
+                                          ((WRegionDoAttachFnSimple*)
+                                           clientwin_do_attach_transient_simple));
+    }
+
+    return ph;
+}
+
+
+WBasicPHolder *clientwin_managed_get_pholder(WClientWin *cwin, WRegion *mgd)
+{
+    return create_basicpholder((WRegion*)cwin, 
+                               ((WRegionDoAttachFnSimple*)
+                                clientwin_do_attach_transient_simple));
 }
 
 
@@ -1067,33 +1183,10 @@ static void do_reparent_clientwin(WClientWin *cwin, Window win, int x, int y)
     XSelectInput(ioncore_g.dpy, cwin->win, cwin->event_mask);
 }
 
-static void convert_geom(WClientWin *cwin, const WFitParams *fp,
-                         WRectangle *geom)
-{
-    const WRectangle *max_geom=&(fp->g);
-    int gravity=cwin->gravity;
-    int htry=max_geom->h;
-    WClientWin *mgr;
-    
-    if(transient_reparents!=NULL && 
-       transient_reparents->transient==(WRegion*)cwin){
-        mgr=transient_reparents->cwin;
-    }else{
-        mgr=REGION_MANAGER_CHK(cwin, WClientWin);
-    }
-    
-    if(mgr!=NULL && fp->mode==REGION_FIT_BOUNDS){
-	if(gravity==ForgetGravity)
-	    gravity=mgr->transient_gravity;
-        if(cwin->last_h_rq<htry)
-            htry=cwin->last_h_rq;
-    }
-    
-    geom->w=max_geom->w;
-    geom->h=htry;
-    
-    xsizehints_correct(&(cwin->size_hints), &(geom->w), &(geom->h), FALSE);
 
+static void do_gravity(const WRectangle *max_geom, int gravity,
+                       WRectangle *geom)
+{
     switch(gravity){
     case WestGravity:
     case NorthWestGravity:
@@ -1135,6 +1228,54 @@ static void convert_geom(WClientWin *cwin, const WFitParams *fp,
 }
 
 
+static void do_convert_geom(int htry, int gravity,
+                            const WRectangle *max_geom,
+                            WRegion *reg, WRectangle *geom)
+{
+    geom->w=max_geom->w;
+    geom->h=minof(htry, max_geom->h);
+    
+    correct_to_size_hints_of(&(geom->w), &(geom->h), reg);
+    do_gravity(max_geom, gravity, geom);
+}
+
+
+static void convert_transient_geom(const WFitParams *fp, 
+                                   WRegion *reg, WRectangle *geom)
+{
+    const WRectangle *max_geom=&(fp->g);
+    int htry=max_geom->h;
+    int gravity=ForgetGravity;
+    
+    if(fp->mode&REGION_FIT_BOUNDS){
+	if(fp->mode&REGION_FIT_GRAVITY)
+            gravity=fp->gravity;
+        if(gravity==ForgetGravity)
+            gravity=SouthGravity;
+        
+        /* TODO: old height after size hint adjustments might be
+         *       zero, while htry result in positive size.
+         */
+        htry=REGION_GEOM(reg).h;
+    }
+    
+    do_convert_geom(htry, gravity, max_geom, reg, geom);
+}
+
+
+static void convert_geom(const WFitParams *fp, 
+                         WClientWin *cwin, WRectangle *geom)
+{
+    WFitParams fptmp=*fp;
+    if(!(fptmp.mode&REGION_FIT_GRAVITY) || fptmp.gravity==ForgetGravity){
+        fptmp.mode|=REGION_FIT_GRAVITY;
+        fptmp.gravity=StaticGravity;
+    }
+
+    convert_transient_geom(&fptmp, (WRegion*)cwin, geom);
+}
+
+
 /*}}}*/
 
 
@@ -1145,9 +1286,18 @@ static void clientwin_managed_rqgeom(WClientWin *cwin, WRegion *sub,
                                      int flags, const WRectangle *geom, 
                                      WRectangle *geomret)
 {
-    WRectangle g=*geom;
+    WRectangle g, *cg=&(cwin->last_fp.g);
 
-    rectangle_constrain(&g, &(cwin->last_fp.g));
+    /* Constrain to cwin's maximum occupied area. */
+    g.w=minof(geom->w, cg->w);
+    g.h=minof(geom->h, cg->h);
+    
+    do_gravity(cg, clientwin_get_transients_gravity(cwin), &g);
+    
+    if(!(flags&REGION_RQGEOM_WEAK_X))
+        g.x=minof(maxof(cg->x, geom->x), cg->x+cg->w-g.w);
+    if(!(flags&REGION_RQGEOM_WEAK_Y))
+        g.y=minof(maxof(cg->y, geom->y), cg->y+cg->h-g.h);
     
     if(geomret!=NULL)
         *geomret=g;
@@ -1158,7 +1308,8 @@ static void clientwin_managed_rqgeom(WClientWin *cwin, WRegion *sub,
 
 
 
-static bool clientwin_fitrep(WClientWin *cwin, WWindow *np, WFitParams *fp)
+static bool clientwin_fitrep(WClientWin *cwin, WWindow *np, 
+                             const WFitParams *fp)
 {
     WRegion *transient, *next;
     WRectangle geom;
@@ -1166,17 +1317,24 @@ static bool clientwin_fitrep(WClientWin *cwin, WWindow *np, WFitParams *fp)
     int diff;
     bool changes;
     int w, h;
+    WFitParams fptmp;
 
     if(np!=NULL && !region_same_rootwin((WRegion*)cwin, (WRegion*)np))
         return FALSE;
 
-    /* Use all available space if NetWM full screen request. */
-    if(cwin->flags&CLIENTWIN_FS_RQ
+    if(fp->mode&REGION_FIT_WHATEVER){
+        /* fp->g is not final geometry; use current size for now. */
+        geom.x=fp->g.x;
+        geom.y=fp->g.y;
+        geom.w=REGION_GEOM(cwin).w;
+        geom.h=REGION_GEOM(cwin).h;
+    }else if(cwin->flags&CLIENTWIN_FS_RQ
        && (OBJ_IS(np, WScreen)
            || (np==NULL && CLIENTWIN_IS_FULLSCREEN(cwin)))){
+        /* Use all available space if NetWM full screen request. */
         geom=fp->g;
     }else{
-        convert_geom(cwin, fp, &geom);
+        convert_geom(fp, cwin, &geom);
     }
 
     changes=(REGION_GEOM(cwin).x!=geom.x ||
@@ -1221,11 +1379,18 @@ static bool clientwin_fitrep(WClientWin *cwin, WWindow *np, WFitParams *fp)
     
     cwin->flags&=~CLIENTWIN_NEED_CFGNTFY;
     
+    fptmp.g=fp->g;
+    fptmp.mode=REGION_FIT_BOUNDS|REGION_FIT_GRAVITY;
+    if(!(fp->mode&REGION_FIT_GRAVITY) || fp->gravity==ForgetGravity)
+        fptmp.gravity=clientwin_get_transients_gravity(cwin);
+    else
+        fptmp.gravity=fp->gravity;
+    
     FOR_ALL_ON_PTRLIST(WRegion*, transient, cwin->transient_list, tmp){
         WFitParams fp2;
-        fp2.g=fp->g;
-        fp2.mode=REGION_FIT_BOUNDS;
-        
+        fp2.mode=REGION_FIT_EXACT;
+        convert_transient_geom(&(fptmp), transient, &(fp2.g));
+
         if(!region_fitrep(transient, np, &fp2) && np!=NULL){
             warn(TR("Error reparenting %s."), region_name(transient));
             region_detach_manager(transient);
@@ -1308,6 +1473,9 @@ static void restack_transients(WClientWin *cwin)
 
 static bool clientwin_managed_goto(WClientWin *cwin, WRegion *sub, int flags)
 {
+    if(flags&REGION_GOTO_ENTERWINDOW)
+        return FALSE;
+    
     if(LATEST_TRANSIENT(cwin)!=sub){
         ptrlist_reinsert_last(&(cwin->transient_list), sub);
         restack_transients(cwin);
@@ -1319,10 +1487,8 @@ static bool clientwin_managed_goto(WClientWin *cwin, WRegion *sub, int flags)
     if(!REGION_IS_MAPPED(sub))
         region_map(sub);
     
-    if(flags&REGION_GOTO_FOCUS){
-        ioncore_set_previous_of(sub);
+    if(flags&REGION_GOTO_FOCUS)
         region_maybewarp(sub, !(flags&REGION_GOTO_NOWARP));
-    }
     
     return TRUE;
 }
@@ -1425,10 +1591,6 @@ ExtlTab clientwin_get_ident(WClientWin *cwin)
 /*{{{ ConfigureRequest */
 
 
-#undef MAX
-#define MAX(X, Y) ((X) > (Y) ? (X) : (Y))
-
-
 void clientwin_handle_configure_request(WClientWin *cwin,
                                         XConfigureRequestEvent *ev)
 {
@@ -1480,7 +1642,7 @@ void clientwin_handle_configure_request(WClientWin *cwin,
                 geom.x+=xgravity_deltax(cwin->size_hints.win_gravity, 0,
                                        ev->width-geom.w);
             }
-            geom.w=MAX(ev->width, 1);
+            geom.w=maxof(ev->width, 1);
             rqflags&=~REGION_RQGEOM_WEAK_W;
         }
         if(ev->value_mask&CWHeight){
@@ -1489,8 +1651,7 @@ void clientwin_handle_configure_request(WClientWin *cwin,
                 geom.y+=xgravity_deltay(cwin->size_hints.win_gravity, 0,
                                        ev->height-geom.h);
             }
-            geom.h=MAX(ev->height, 1);
-            cwin->last_h_rq=geom.h;
+            geom.h=maxof(ev->height, 1);
             rqflags&=~REGION_RQGEOM_WEAK_H;
         }
         if(ev->value_mask&CWX){
@@ -1507,11 +1668,15 @@ void clientwin_handle_configure_request(WClientWin *cwin,
             /* Manager gets to decide how to handle position request. */
             region_rqgeom_clientwin(mgr, cwin, rqflags, &geom);
         }else{
-            /*region_convert_root_geom(region_parent((WRegion*)cwin),
+            region_convert_root_geom(REGION_PARENT_REG((WRegion*)cwin),
                                      &geom);
-            region_rqgeom((WRegion*)cwin, rqflags, &geom, NULL);*/
+            rqflags|=(REGION_RQGEOM_WEAK_X|REGION_RQGEOM_WEAK_Y);
+            region_rqgeom((WRegion*)cwin, rqflags, &geom, NULL);
             /* Just use any known available space wanted or give up some */
-            region_fitrep((WRegion*)cwin, NULL, &(cwin->last_fp));
+            /* Temporary hack. */
+            /*REGION_GEOM(cwin).w=geom.w;
+            REGION_GEOM(cwin).h=geom.h;
+            region_fitrep((WRegion*)cwin, NULL, &(cwin->last_fp));*/
         }
     }
 
@@ -1579,8 +1744,9 @@ void clientwin_toggle_transients_pos(WClientWin *cwin)
     else
 	cwin->transient_gravity=NorthGravity;
 
-    fp.mode=REGION_FIT_BOUNDS;
+    fp.mode=REGION_FIT_BOUNDS|REGION_FIT_GRAVITY;
     fp.g=cwin->last_fp.g;
+    fp.gravity=clientwin_get_transients_gravity(cwin);
     
     FOR_ALL_ON_PTRLIST(WRegion*, transient, cwin->transient_list, tmp){
         region_fitrep(transient, NULL, &fp);
@@ -1608,7 +1774,7 @@ double clientwin_xid(WClientWin *cwin)
 /*}}}*/
 
 
-/*{{{Save/load */
+/*{{{ Save/load */
 
 
 static int last_checkcode=1;
@@ -1695,7 +1861,7 @@ WRegion *clientwin_load(WWindow *par, const WFitParams *fp, ExtlTab tab)
         return FALSE;
     
     /* Reparent and resize taking limits set by size hints into account */
-    convert_geom(cwin, fp, &rg);
+    convert_geom(fp, cwin, &rg);
     REGION_GEOM(cwin)=rg;
     do_reparent_clientwin(cwin, par->win, rg.x, rg.y);
     XResizeWindow(ioncore_g.dpy, win, maxof(1, rg.w), maxof(1, rg.h));
@@ -1767,8 +1933,14 @@ static DynFunTab clientwin_dynfuntab[]={
     {(DynFun*)region_rescue_clientwins,
      (DynFun*)clientwin_rescue_clientwins},
     
-    {(DynFun*)region_manage_clientwin,
-     (DynFun*)clientwin_manage_clientwin},
+    {(DynFun*)region_prepare_manage,
+     (DynFun*)clientwin_prepare_manage},
+
+    {(DynFun*)region_prepare_manage_transient,
+     (DynFun*)clientwin_prepare_manage_transient},
+
+    {(DynFun*)region_managed_get_pholder,
+     (DynFun*)clientwin_managed_get_pholder},
 
     END_DYNFUNTAB
 };
