@@ -1,7 +1,7 @@
 /*
  * ion/ioncore/key.h
  *
- * Copyright (c) Tuomo Valkonen 1999-2004. 
+ * Copyright (c) Tuomo Valkonen 1999-2006. 
  *
  * Ion is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by
@@ -17,7 +17,7 @@
 #include "common.h"
 #include "clientwin.h"
 
-extern void handle_keypress(XKeyEvent *ev);
+extern void ioncore_do_handle_keypress(XKeyEvent *ev);
 extern void clientwin_quote_next(WClientWin *cwin);
 
 #endif /* ION_IONCORE_KEY_H */
