@@ -1,7 +1,7 @@
 /*
  * ion/ioncore/mplex.c
  *
- * Copyright (c) Tuomo Valkonen 1999-2005. 
+ * Copyright (c) Tuomo Valkonen 1999-2006. 
  *
  * Ion is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by
@@ -63,8 +63,9 @@ bool mplex_do_init(WMPlex *mplex, WWindow *parent, Window win,
     mplex->l2_current=NULL;
     mplex->l2_phs=NULL;
     
-    watch_init(&(mplex->stdispinfo.regwatch));
+    watch_init(&(mplex->stdispwatch));
     mplex->stdispinfo.pos=MPLEX_STDISP_BL;
+    mplex->stdispinfo.fullsize=FALSE;
     
     if(create){
         if(!window_init((WWindow*)mplex, parent, fp))
@@ -323,7 +324,7 @@ void mplex_dec_index(WMPlex *mplex, WRegion *r)
 /*}}}*/
 
 
-/*{{{Mapping */
+/*{{{ Mapping */
 
 
 static void mplex_map_mgd(WMPlex *mplex)
@@ -398,39 +399,47 @@ bool mplex_fitrep(WMPlex *mplex, WWindow *par, const WFitParams *fp)
 }
 
 
-void mplex_fit_managed(WMPlex *mplex)
+void mplex_do_fit_managed(WMPlex *mplex, WFitParams *fp)
 {
     WRectangle geom;
     WRegion *sub;
-    WFitParams fp;
     WLListIterTmp tmp;
     
-    mplex_managed_geom(mplex, &(fp.g));
-    
-    if(!MPLEX_MGD_UNVIEWABLE(mplex) && (fp.g.w<=1 || fp.g.h<=1)){
+    if(!MPLEX_MGD_UNVIEWABLE(mplex) && (fp->g.w<=1 || fp->g.h<=1)){
         mplex->flags|=MPLEX_MANAGED_UNVIEWABLE;
         if(REGION_IS_MAPPED(mplex))
             mplex_unmap_mgd(mplex);
-    }else if(MPLEX_MGD_UNVIEWABLE(mplex) && !(fp.g.w<=1 || fp.g.h<=1)){
+    }else if(MPLEX_MGD_UNVIEWABLE(mplex) && !(fp->g.w<=1 || fp->g.h<=1)){
         mplex->flags&=~MPLEX_MANAGED_UNVIEWABLE;
         if(REGION_IS_MAPPED(mplex))
             mplex_map_mgd(mplex);
     }
     
     if(!MPLEX_MGD_UNVIEWABLE(mplex)){
-        fp.mode=REGION_FIT_EXACT;
+        fp->mode&=~REGION_FIT_BOUNDS;
         FOR_ALL_REGIONS_ON_LLIST(sub, mplex->l1_list, tmp){
-            region_fitrep(sub, NULL, &fp);
+            region_fitrep(sub, NULL, fp);
         }
         
-        fp.mode=REGION_FIT_BOUNDS;
+        fp->mode|=REGION_FIT_BOUNDS;
         FOR_ALL_REGIONS_ON_LLIST(sub, mplex->l2_list, tmp){
-            region_fitrep(sub, NULL, &fp);
+            region_fitrep(sub, NULL, fp);
         }
     }
 }
 
 
+void mplex_fit_managed(WMPlex *mplex)
+{
+    WFitParams fp;
+    
+    fp.mode=REGION_FIT_EXACT;
+    mplex_managed_geom(mplex, &(fp.g));
+
+    mplex_do_fit_managed(mplex, &fp);
+}
+
+
 static void mplex_managed_rqgeom(WMPlex *mplex, WRegion *sub,
                                  int flags, const WRectangle *geom, 
                                  WRectangle *geomret)
@@ -501,14 +510,14 @@ void mplex_managed_activated(WMPlex *mplex, WRegion *reg)
 /*{{{ Managed region switching */
 
 
-static bool mplex_l2_try_make_passive(WMPlex *mplex)
+static bool mplex_l2_try_make_passive(WMPlex *mplex, bool nohide)
 {
     WLListNode *node;
     bool tohide=FALSE;
     
     FOR_ALL_NODES_ON_LLIST(node, mplex->l2_list){
         if((node->flags&(LLIST_L2_HIDDEN|LLIST_L2_PASSIVE))==0){
-            if(node->flags&LLIST_L2_SEMIMODAL)
+            if(node->flags&LLIST_L2_SEMIMODAL || nohide)
                 return FALSE;
             tohide=TRUE;
         }
@@ -531,7 +540,7 @@ static bool mplex_l2_try_make_passive(WMPlex *mplex)
 
 
 static bool mplex_do_node_display(WMPlex *mplex, WLListNode *node,
-                                  bool call_changed)
+                                  bool call_changed, bool nohide)
 {
     WRegion *sub=node->reg;
     bool l2=node->flags&LLIST_L2;
@@ -540,10 +549,10 @@ static bool mplex_do_node_display(WMPlex *mplex, WLListNode *node,
         if(node==mplex->l2_current)
             return TRUE;
     }else{
-        WRegion *stdisp=(WRegion*)(mplex->stdispinfo.regwatch.obj);
+        WRegion *stdisp=(WRegion*)(mplex->stdispwatch.obj);
 
         if(node==mplex->l1_current)
-            return mplex_l2_try_make_passive(mplex);
+            return mplex_l2_try_make_passive(mplex, nohide);
         
         /* Move stdisp */
         if(OBJ_IS(sub, WGenWS)){
@@ -556,11 +565,13 @@ static bool mplex_do_node_display(WMPlex *mplex, WLListNode *node,
                     }
                     
                     genws_manage_stdisp((WGenWS*)sub, stdisp, 
-                                        mplex->stdispinfo.pos);
+                                        &(mplex->stdispinfo));
                 }
             }else{
                 genws_unmanage_stdisp((WGenWS*)sub, TRUE, FALSE);
             }
+        }else if(stdisp!=NULL){
+            region_unmap(stdisp);
         }
     }
     
@@ -590,7 +601,7 @@ static bool mplex_do_node_display(WMPlex *mplex, WLListNode *node,
         mplex_managed_activated(mplex, sub);
 
         mplex_managed_changed(mplex, MPLEX_CHANGE_SWITCHONLY, TRUE, sub);
-        return mplex_l2_try_make_passive(mplex);
+        return mplex_l2_try_make_passive(mplex, nohide);
     }else{
         mplex_move_phs_before(mplex, node);
         llist_unlink(&(mplex->l2_list), node);
@@ -608,37 +619,36 @@ static bool mplex_do_node_display(WMPlex *mplex, WLListNode *node,
 
 
 static bool mplex_do_node_goto(WMPlex *mplex, WLListNode *node,
-                               bool call_changed, int flags)
+                               bool call_changed, bool nohide, int flags)
 {
-    if(!mplex_do_node_display(mplex, node, call_changed))
+    if(!mplex_do_node_display(mplex, node, call_changed, nohide))
         return FALSE;
     
-    if(flags&REGION_GOTO_FOCUS){
-        ioncore_set_previous_of(node->reg);
+    if(flags&REGION_GOTO_FOCUS)
         region_maybewarp(node->reg, !(flags&REGION_GOTO_NOWARP));
-    }
     
     return TRUE;
 }
 
 
 static bool mplex_do_node_goto_sw(WMPlex *mplex, WLListNode *node,
-                                  bool call_changed)
+                                  bool call_changed, bool nohide)
 {
     bool mcf=region_may_control_focus((WRegion*)mplex);
     int flags=(mcf ? REGION_GOTO_FOCUS : 0)|REGION_GOTO_NOWARP;
-    return mplex_do_node_goto(mplex, node, call_changed, flags);
+    return mplex_do_node_goto(mplex, node, call_changed, nohide, flags);
 }
 
 
 bool mplex_managed_goto(WMPlex *mplex, WRegion *sub, int flags)
 {
     WLListNode *node=mplex_find_node(mplex, sub);
-    
+    bool nohide=(flags&REGION_GOTO_ENTERWINDOW);
+
     if(node==NULL)
         return FALSE;
     else
-        return mplex_do_node_goto(mplex, node, TRUE, flags);
+        return mplex_do_node_goto(mplex, node, TRUE, nohide, flags);
 }
 
 
@@ -653,7 +663,6 @@ static void mplex_refocus(WMPlex *mplex, bool warp)
     else
         reg=(WRegion*)mplex;
     
-    ioncore_set_previous_of(reg);
     region_maybewarp(reg, warp);
 }
 
@@ -662,8 +671,9 @@ static void do_switch(WMPlex *mplex, WLListNode *node)
 {
     if(node!=NULL){
         bool mcf=region_may_control_focus((WRegion*)mplex);
-        region_managed_goto((WRegion*)mplex, node->reg,
-                            (mcf ? REGION_GOTO_FOCUS : 0));
+
+        mplex_do_node_goto(mplex, node, TRUE, TRUE, 
+                           (mcf ? REGION_GOTO_FOCUS : 0));
     }
 }
 
@@ -733,7 +743,7 @@ bool mplex_l2_set_hidden(WMPlex *mplex, WRegion *reg, bool sp)
             mplex_refocus(mplex, TRUE);
     }else if(hidden && !nhidden){
         bool psv=node->flags&LLIST_L2_PASSIVE;
-        mplex_do_node_goto(mplex, node, TRUE,
+        mplex_do_node_goto(mplex, node, TRUE, TRUE,
                            (mcf && !psv ? REGION_GOTO_FOCUS : 0));
     }
     
@@ -897,9 +907,9 @@ WLListNode *mplex_do_attach_after(WMPlex *mplex,
     }
     
     if(sw)
-        mplex_do_node_goto_sw(mplex, node, FALSE);
+        mplex_do_node_goto_sw(mplex, node, FALSE, TRUE);
     else if(l2 && !(node->flags&LLIST_L2_HIDDEN))
-        mplex_do_node_display(mplex, node, FALSE);
+        mplex_do_node_display(mplex, node, FALSE, TRUE);
     else
         region_unmap(reg);
 
@@ -937,7 +947,7 @@ WRegion *mplex_attach_simple(WMPlex *mplex, WRegion *reg, int flags)
     if(reg==(WRegion*)mplex)
         return FALSE;
     
-    par.index=DEFAULT_INDEX(mplex);
+    par.index=mplex_default_index(mplex);
     par.flags=flags;
     
     return region__attach_reparent((WRegion*)mplex, reg,
@@ -951,7 +961,7 @@ WRegion *mplex_attach_hnd(WMPlex *mplex, WRegionAttachHandler *hnd,
 {
     WMPlexAttachParams par;
     
-    par.index=DEFAULT_INDEX(mplex);
+    par.index=mplex_default_index(mplex);
     par.flags=flags&~MPLEX_ATTACH_L2_GEOM;
     
     return mplex_do_attach(mplex, hnd, hnd_param, &par);
@@ -963,7 +973,7 @@ static void get_params(WMPlex *mplex, ExtlTab tab, WMPlexAttachParams *par)
     int layer=1;
     
     par->flags=0;
-    par->index=DEFAULT_INDEX(mplex);
+    par->index=mplex_default_index(mplex);
     
     extl_table_gets_i(tab, "layer", &layer);
     if(layer==2){
@@ -999,7 +1009,7 @@ WRegion *mplex_attach(WMPlex *mplex, WRegion *reg, ExtlTab param)
     
     /* region__attach_reparent should do better checks. */
     if(reg==NULL || reg==(WRegion*)mplex)
-        return FALSE;
+        return NULL;
     
     return region__attach_reparent((WRegion*)mplex, reg,
                                    (WRegionDoAttachFn*)mplex_do_attach, 
@@ -1070,42 +1080,45 @@ static bool mplex_handle_drop(WMPlex *mplex, int x, int y,
 }
 
 
-bool mplex_manage_clientwin(WMPlex *mplex, WClientWin *cwin,
-                            const WManageParams *param, int redir)
+WPHolder *mplex_prepare_manage(WMPlex *mplex, const WClientWin *cwin,
+                               const WManageParams *param, int redir)
 {
     int swf=(param->switchto ? MPLEX_ATTACH_SWITCHTO : 0);
+    WPHolder *ph=NULL;
     
     if(redir==MANAGE_REDIR_STRICT_YES || redir==MANAGE_REDIR_PREFER_YES){
         if(mplex->l2_current!=NULL){
-            if(region_manage_clientwin(mplex->l2_current->reg, cwin, param,
-                                       MANAGE_REDIR_PREFER_YES))
-                return TRUE;
+            ph=region_prepare_manage(mplex->l2_current->reg, cwin, param,
+                                     MANAGE_REDIR_PREFER_YES);
+            if(ph!=NULL)
+                return ph;
         }
         if(mplex->l1_current!=NULL){
-            if(region_manage_clientwin(mplex->l1_current->reg, cwin, param,
-                                       MANAGE_REDIR_PREFER_YES))
-                return TRUE;
+            ph=region_prepare_manage(mplex->l1_current->reg, cwin, param,
+                                     MANAGE_REDIR_PREFER_YES);
+            if(ph!=NULL)
+                return ph;
         }
     }
     
     if(redir==MANAGE_REDIR_STRICT_YES)
-        return FALSE;
+        return NULL;
     
-    return (NULL!=mplex_attach_simple(mplex, (WRegion*)cwin, swf));
+    return (WPHolder*)create_mplexpholder(mplex, NULL, mplex->l1_current, 1);
 }
 
 
 /*}}}*/
 
 
-/*{{{Remove */
+/*{{{ Remove */
 
 
 void mplex_managed_remove(WMPlex *mplex, WRegion *sub)
 {
     bool l2=FALSE;
     bool sw=FALSE;
-    WRegion *stdisp=(WRegion*)(mplex->stdispinfo.regwatch.obj);
+    WRegion *stdisp=(WRegion*)(mplex->stdispwatch.obj);
     WLListNode *node, *next=NULL;
     
     if(OBJ_IS(sub, WGenWS) && stdisp!=NULL && REGION_MANAGER(stdisp)==sub){
@@ -1162,7 +1175,7 @@ void mplex_managed_remove(WMPlex *mplex, WRegion *sub)
         return;
     
     if(next!=NULL && sw)
-        mplex_do_node_goto_sw(mplex, next, FALSE);
+        mplex_do_node_goto_sw(mplex, next, FALSE, TRUE);
     else if(l2 && region_may_control_focus((WRegion*)mplex))
         region_warp((WRegion*)mplex);
     
@@ -1195,11 +1208,9 @@ bool mplex_rescue_clientwins(WMPlex *mplex, WPHolder *ph)
 
 void mplex_child_removed(WMPlex *mplex, WRegion *sub)
 {
-    WMPlexSTDispInfo *di=&(mplex->stdispinfo);
-    
-    if(sub==(WRegion*)(di->regwatch.obj)){
-        watch_reset(&(di->regwatch));
-        mplex_set_stdisp(mplex, NULL, di->pos);
+    if(sub!=NULL && sub==(WRegion*)(mplex->stdispwatch.obj)){
+        watch_reset(&(mplex->stdispwatch));
+        mplex_set_stdisp(mplex, NULL, NULL);
     }
 }
 
@@ -1229,13 +1240,13 @@ static void stdisp_watch_handler(Watch *watch, Obj *obj)
 }
 
 
-bool mplex_set_stdisp(WMPlex *mplex, WRegion *reg, int pos)
+bool mplex_set_stdisp(WMPlex *mplex, WRegion *reg, 
+                      const WMPlexSTDispInfo *din)
 {
-    WMPlexSTDispInfo *di=&(mplex->stdispinfo);
-    WRegion *oldstdisp=(WRegion*)(di->regwatch.obj);
+    WRegion *oldstdisp=(WRegion*)(mplex->stdispwatch.obj);
     WGenWS *mgr=NULL;
     
-    assert(reg==NULL || (Obj*)reg==di->regwatch.obj ||
+    assert(reg==NULL || (reg==oldstdisp) ||
            (REGION_MANAGER(reg)==NULL && 
             REGION_PARENT(reg)==(WWindow*)mplex));
     
@@ -1243,20 +1254,22 @@ bool mplex_set_stdisp(WMPlex *mplex, WRegion *reg, int pos)
         mgr=OBJ_CAST(REGION_MANAGER(oldstdisp), WGenWS);
         
         if(oldstdisp!=reg){
-            mainloop_defer_destroy(di->regwatch.obj);
-            watch_reset(&(di->regwatch));
+            mainloop_defer_destroy((Obj*)oldstdisp);
+            watch_reset(&(mplex->stdispwatch));
         }
     }
     
-    di->pos=pos;
+    if(din!=NULL)
+        mplex->stdispinfo=*din;
     
     if(reg==NULL){
         if(mgr!=NULL){
             genws_unmanage_stdisp((WGenWS*)mgr, TRUE, FALSE);
-            region_detach_manager(oldstdisp);
+            if(oldstdisp!=NULL)
+                region_detach_manager(oldstdisp);
         }
     }else{
-        watch_setup(&(di->regwatch), (Obj*)reg, stdisp_watch_handler);
+        watch_setup(&(mplex->stdispwatch), (Obj*)reg, stdisp_watch_handler);
         
         if(mplex->l1_current!=NULL
            && OBJ_IS(mplex->l1_current->reg, WGenWS)
@@ -1268,7 +1281,7 @@ bool mplex_set_stdisp(WMPlex *mplex, WRegion *reg, int pos)
             mgr=(WGenWS*)(mplex->l1_current->reg);
         }
         if(mgr!=NULL)
-            genws_manage_stdisp(mgr, reg, di->pos);
+            genws_manage_stdisp(mgr, reg, &(mplex->stdispinfo));
         else
             region_unmap(reg);
     }
@@ -1277,12 +1290,10 @@ bool mplex_set_stdisp(WMPlex *mplex, WRegion *reg, int pos)
 }
 
 
-void mplex_get_stdisp(WMPlex *mplex, WRegion **reg, int *pos)
+void mplex_get_stdisp(WMPlex *mplex, WRegion **reg, WMPlexSTDispInfo *di)
 {
-    WMPlexSTDispInfo *di=&(mplex->stdispinfo);
-    
-    *reg=(WRegion*)di->regwatch.obj;
-    *pos=di->pos;
+    *di=mplex->stdispinfo;
+    *reg=(WRegion*)mplex->stdispwatch.obj;
 }
 
 
@@ -1328,17 +1339,19 @@ EXTL_EXPORT_AS(WMPlex, set_stdisp)
 WRegion *mplex_set_stdisp_extl(WMPlex *mplex, ExtlTab t)
 {
     WRegion *stdisp=NULL;
-    int p=mplex->stdispinfo.pos;
+    WMPlexSTDispInfo din=mplex->stdispinfo;
     char *s;
     
     if(extl_table_gets_s(t, "pos", &s)){
-        p=stringintmap_value(pos_map, s, -1);
-        if(p<0){
+        din.pos=stringintmap_value(pos_map, s, -1);
+        if(din.pos<0){
             warn(TR("Invalid position setting."));
             return NULL;
         }
     }
     
+    extl_table_gets_b(t, "fullsize", &(din.fullsize));
+    
     s=NULL;
     extl_table_gets_s(t, "action", &s);
     
@@ -1365,13 +1378,13 @@ WRegion *mplex_set_stdisp_extl(WMPlex *mplex, ExtlTab t)
             return NULL;
         
     }else if(strcmp(s, "keep")==0){
-        stdisp=(WRegion*)(mplex->stdispinfo.regwatch.obj);
+        stdisp=(WRegion*)(mplex->stdispwatch.obj);
     }else if(strcmp(s, "remove")!=0){
         warn(TR("Invalid action setting."));
         return FALSE;
     }
     
-    if(!mplex_set_stdisp(mplex, stdisp, p)){
+    if(!mplex_set_stdisp(mplex, stdisp, &din)){
         destroy_obj((Obj*)stdisp);
         return NULL;
     }
@@ -1382,23 +1395,25 @@ WRegion *mplex_set_stdisp_extl(WMPlex *mplex, ExtlTab t)
 
 static ExtlTab mplex_do_get_stdisp_extl(WMPlex *mplex, bool fullconfig)
 {
-    WMPlexSTDispInfo *di=&(mplex->stdispinfo);
+    WRegion *reg=(WRegion*)mplex->stdispwatch.obj;
     ExtlTab t;
     
-    if(di->regwatch.obj==NULL)
+    if(reg==NULL)
         return extl_table_none();
     
     if(fullconfig){
-        t=region_get_configuration((WRegion*)di->regwatch.obj);
-        extl_table_sets_rectangle(t, "geom", &REGION_GEOM(di->regwatch.obj));
+        t=region_get_configuration(reg);
+        extl_table_sets_rectangle(t, "geom", &REGION_GEOM(reg));
     }else{
         t=extl_create_table();
-        extl_table_sets_o(t, "reg", di->regwatch.obj);
+        extl_table_sets_o(t, "reg", (Obj*)reg);
     }
     
-    if(t!=extl_table_none())
+    if(t!=extl_table_none()){
+        WMPlexSTDispInfo *di=&(mplex->stdispinfo);
         extl_table_sets_s(t, "pos", stringintmap_key(pos_map, di->pos, NULL));
-    
+        extl_table_sets_b(t, "fullsize", di->fullsize);
+    }
     return t;
 }
 
@@ -1448,6 +1463,14 @@ void mplex_managed_changed(WMPlex *mplex, int mode, bool sw, WRegion *mgd)
 }
 
 
+int mplex_default_index(WMPlex *mplex)
+{
+    int idx=LLIST_INDEX_LAST;
+    CALL_DYN_RET(idx, int, mplex_default_index, mplex, (mplex));
+    return idx;
+}
+
+
 /*}}}*/
 
 
@@ -1651,8 +1674,8 @@ static DynFunTab mplex_dynfuntab[]={
     {region_map, mplex_map},
     {region_unmap, mplex_unmap},
     
-    {(DynFun*)region_manage_clientwin,
-     (DynFun*)mplex_manage_clientwin},
+    {(DynFun*)region_prepare_manage,
+     (DynFun*)mplex_prepare_manage},
     
     {(DynFun*)region_current,
      (DynFun*)mplex_current},
