@@ -1,7 +1,7 @@
 /*
  * ion/ioncore/mplex.h
  *
- * Copyright (c) Tuomo Valkonen 1999-2005. 
+ * Copyright (c) Tuomo Valkonen 1999-2006. 
  * 
  * Ion is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by
@@ -57,8 +57,8 @@ INTRSTRUCT(WLListNode); /* in mplexp.h */
 
 
 DECLSTRUCT(WMPlexSTDispInfo){
-    Watch regwatch;
     int pos;
+    bool fullsize;
 };
 
 
@@ -91,6 +91,7 @@ DECLCLASS(WMPlex){
     WLListNode *l2_current;
     WMPlexPHolder *l2_phs;
     
+    Watch stdispwatch;
     WMPlexSTDispInfo stdispinfo;
 };
 
@@ -107,6 +108,7 @@ extern void mplex_deinit(WMPlex *mplex);
 /* Resize and reparent */
 
 extern bool mplex_fitrep(WMPlex *mplex, WWindow *par, const WFitParams *fp);
+extern void mplex_do_fit_managed(WMPlex *mplex, WFitParams *fp);
 extern void mplex_fit_managed(WMPlex *mplex);
 
 /* Mapping */
@@ -139,8 +141,8 @@ extern void mplex_child_removed(WMPlex *mplex, WRegion *sub);
 
 extern bool mplex_rescue_clientwins(WMPlex *mplex, WPHolder *ph);
 
-extern bool mplex_manage_clientwin(WMPlex *mplex, WClientWin *cwin,
-                                   const WManageParams *param, int redir);
+extern WPHolder *mplex_prepare_manage(WMPlex *mplex, const WClientWin *cwin,
+                                      const WManageParams *param, int redir);
 
 /* Switch */
 
@@ -180,6 +182,7 @@ DYNFUN void mplex_managed_geom(const WMPlex *mplex, WRectangle *geom);
 DYNFUN void mplex_size_changed(WMPlex *mplex, bool wchg, bool hchg);
 DYNFUN void mplex_managed_changed(WMPlex *mplex, int what, bool sw,
                                   WRegion *mgd);
+DYNFUN int mplex_default_index(WMPlex *mplex);
 
 /* Save/load */
 
@@ -190,8 +193,10 @@ extern void mplex_load_contents(WMPlex *frame, ExtlTab tab);
 
 /* Sticky status display support */
 
-extern bool mplex_set_stdisp(WMPlex *mplex, WRegion *stdisp, int pos);
-extern void mplex_get_stdisp(WMPlex *mplex, WRegion **stdisp, int *pos);
+extern bool mplex_set_stdisp(WMPlex *mplex, WRegion *stdisp, 
+                             const WMPlexSTDispInfo *info);
+extern void mplex_get_stdisp(WMPlex *mplex, WRegion **stdisp, 
+                             WMPlexSTDispInfo *info);
 
 extern WRegion *mplex_set_stdisp_extl(WMPlex *mplex, ExtlTab t);
 extern ExtlTab mplex_get_stdisp_extl(WMPlex *mplex);
