@@ -15,21 +15,36 @@
 #include "region.h"
 #include "clientwin.h"
 #include "gr.h"
-#include "extl.h"
+#include <libextl/extl.h>
 
-extern bool region_init_name(WRegion *reg, const char *name);
+
+typedef struct{
+    struct rb_node *rb;
+    bool initialised;
+} WNamespace;
+
+
+extern WNamespace ioncore_internal_ns;
+extern WNamespace ioncore_clientwin_ns;
+
+
+extern bool region_register(WRegion *reg);
 extern bool region_set_name(WRegion *reg, const char *name);
 extern bool region_set_name_exact(WRegion *reg, const char *name);
+
+extern bool clientwin_register(WClientWin *cwin);
 extern bool clientwin_set_name(WClientWin *cwin, const char *name);
-extern void    region_unuse_name(WRegion *reg);
+
+extern void region_unregister(WRegion *reg);
+extern void region_do_unuse_name(WRegion *reg, bool insert_unnamed);
 
 extern const char *region_name(WRegion *reg);
 
 extern char *region_make_label(WRegion *reg, int maxw, GrBrush *brush);
 
-extern WRegion *lookup_region(const char *cname, const char *typenam);
-extern ExtlTab complete_region(const char *nam, const char *typenam);
-extern WClientWin *lookup_clientwin(const char *cname);
-extern ExtlTab complete_clientwin(const char *nam);
+extern ExtlTab ioncore_region_list(const char *typenam);
+extern ExtlTab ioncore_clientwin_list();
+extern WRegion *ioncore_lookup_region(const char *cname, const char *typenam);
+extern WClientWin *ioncore_lookup_clientwin(const char *cname);
 
 #endif /* ION_IONCORE_NAMES_H */
