@@ -1,7 +1,7 @@
 /* 
  * ion/ioncore/resize.c
  *
- * Copyright (c) Tuomo Valkonen 1999-2005. 
+ * Copyright (c) Tuomo Valkonen 1999-2006. 
  *
  * Ion is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by
@@ -265,8 +265,8 @@ static bool moveresmode_init(WMoveresMode *mode, WRegion *reg,
     
     /* Set up info window */
     {
-        int x=mode->parent_rx+mode->geom.x+mode->geom.w/2;
-        int y=mode->parent_ry+mode->geom.y+mode->geom.h/2;
+        int x=mode->geom.x+mode->geom.w/2;
+        int y=mode->geom.y+mode->geom.h/2;
         mode->infowin=setup_moveres_display(parent, x, y);
     }
                                         
@@ -322,7 +322,7 @@ static void moveresmode_delta(WMoveresMode *mode,
                               WRectangle *rret)
 {
     WRectangle geom;
-    int w, h;
+    int w=0, h=0;
     int realdx1, realdx2, realdy1, realdy2;
     
     realdx1=(mode->dx1+=dx1);
@@ -594,7 +594,7 @@ void region_size_hints(WRegion *reg, XSizeHints *hints_ret)
         hints_ret->max_width=INT_MAX;
         hints_ret->max_height=INT_MAX;
     }
-    hints_ret->flags|=(PMinSize|PBaseSize|PMaxSize);
+    /*hints_ret->flags|=(PMinSize|PBaseSize|PMaxSize);*/
 }
 
 
