@@ -1,7 +1,7 @@
 /*
  * ion/ioncore/rootwin.c
  *
- * Copyright (c) Tuomo Valkonen 1999-2004. 
+ * Copyright (c) Tuomo Valkonen 1999-2006. 
  *
  * Ion is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by
@@ -25,8 +25,8 @@
 #include <X11/extensions/Xinerama.h>
 #endif
 
+#include <libtu/objp.h>
 #include "common.h"
-#include "objp.h"
 #include "rootwin.h"
 #include "cursor.h"
 #include "global.h"
@@ -39,10 +39,11 @@
 #include "screen.h"
 #include "screen.h"
 #include "bindmaps.h"
-#include "readconfig.h"
+#include <libextl/readconfig.h>
 #include "resize.h"
 #include "saveload.h"
 #include "netwm.h"
+#include "xwindow.h"
 
 
 /*{{{ Error handling */
@@ -100,27 +101,6 @@ static int my_error_handler(Display *dpy, XErrorEvent *ev)
 /*}}}*/
 
 
-/*{{{ Utility functions */
-
-
-Window create_simple_window(WRootWin *rw, Window par, const WRectangle *geom)
-{
-    int w=geom->w;
-    int h=geom->h;
-    
-    if(w<=0)
-        w=1;
-    if(h<=0)
-        h=1;
-    
-    return XCreateSimpleWindow(wglobal.dpy, par, geom->x, geom->y, w, h,
-                               0, 0, BlackPixel(wglobal.dpy, rw->xscr));
-}
-
-
-/*}}}*/
-
-
 /*{{{ Init/deinit */
 
 
@@ -130,13 +110,13 @@ static void scan_initial_windows(WRootWin *rootwin)
     uint nwins=0, i, j;
     XWMHints *hints;
     
-    XQueryTree(wglobal.dpy, WROOTWIN_ROOT(rootwin), &dummy_root, &dummy_parent,
+    XQueryTree(ioncore_g.dpy, WROOTWIN_ROOT(rootwin), &dummy_root, &dummy_parent,
                &wins, &nwins);
     
     for(i=0; i<nwins; i++){
         if(wins[i]==None)
             continue;
-        hints=XGetWMHints(wglobal.dpy, wins[i]);
+        hints=XGetWMHints(ioncore_g.dpy, wins[i]);
         if(hints!=NULL && hints->flags&IconWindowHint){
             for(j=0; j<nwins; j++){
                 if(wins[j]==hints->icon_window){
@@ -164,20 +144,20 @@ void rootwin_manage_initial_windows(WRootWin *rootwin)
     rootwin->tmpnwins=0;
     
     for(i=0; i<nwins; i++){
-        if(FIND_WINDOW(wins[i])!=NULL)
+        if(XWINDOW_REGION_OF(wins[i])!=NULL)
             wins[i]=None;
         if(wins[i]==None)
             continue;
-        if(XGetTransientForHint(wglobal.dpy, wins[i], &tfor))
+        if(XGetTransientForHint(ioncore_g.dpy, wins[i], &tfor))
             continue;
-        manage_clientwin(wins[i], MANAGE_INITIAL);
+        ioncore_manage_clientwin(wins[i], FALSE);
         wins[i]=None;
     }
 
     for(i=0; i<nwins; i++){
         if(wins[i]==None)
             continue;
-        manage_clientwin(wins[i], MANAGE_INITIAL);
+        ioncore_manage_clientwin(wins[i], FALSE);
     }
     
     XFree((void*)wins);
@@ -186,12 +166,12 @@ void rootwin_manage_initial_windows(WRootWin *rootwin)
 
 static void create_wm_windows(WRootWin *rootwin)
 {
-    rootwin->dummy_win=XCreateWindow(wglobal.dpy, WROOTWIN_ROOT(rootwin),
+    rootwin->dummy_win=XCreateWindow(ioncore_g.dpy, WROOTWIN_ROOT(rootwin),
                                      0, 0, 1, 1, 0,
                                      CopyFromParent, InputOnly,
                                      CopyFromParent, 0, NULL);
 
-    XSelectInput(wglobal.dpy, rootwin->dummy_win, PropertyChangeMask);
+    XSelectInput(ioncore_g.dpy, rootwin->dummy_win, PropertyChangeMask);
 }
 
 
@@ -214,16 +194,16 @@ static void preinit_gr(WRootWin *rootwin)
              GCJoinStyle|GCCapStyle|GCFunction|
              GCSubwindowMode|GCForeground);
 
-    rootwin->xor_gc=XCreateGC(wglobal.dpy, WROOTWIN_ROOT(rootwin), 
+    rootwin->xor_gc=XCreateGC(ioncore_g.dpy, WROOTWIN_ROOT(rootwin), 
                               gcvmask, &gcv);
 }
 
 
 static WRootWin *preinit_rootwin(int xscr)
 {
-    Display *dpy=wglobal.dpy;
+    Display *dpy=ioncore_g.dpy;
     WRootWin *rootwin;
-    WRectangle geom;
+    WFitParams fp;
     Window root;
     int i;
     
@@ -233,46 +213,48 @@ static WRootWin *preinit_rootwin(int xscr)
     redirect_error=FALSE;
 
     XSetErrorHandler(my_redirect_error_handler);
-    XSelectInput(dpy, root, ROOT_MASK);
+    XSelectInput(dpy, root, IONCORE_EVENTMASK_ROOT);
     XSync(dpy, 0);
     XSetErrorHandler(my_error_handler);
 
     if(redirect_error){
-        warn("Unable to redirect root window events for screen %d.", xscr);
+        warn(TR("Unable to redirect root window events for screen %d."),
+             xscr);
         return NULL;
     }
     
     rootwin=ALLOC(WRootWin);
     
-    if(rootwin==NULL){
-        warn_err();
+    if(rootwin==NULL)
         return NULL;
-    }
     
     /* Init the struct */
-    WOBJ_INIT(rootwin, WRootWin);
+    OBJ_INIT(rootwin, WRootWin);
 
     rootwin->xscr=xscr;
     rootwin->default_cmap=DefaultColormap(dpy, xscr);
-    rootwin->screen_list=NULL;
     rootwin->tmpwins=NULL;
     rootwin->tmpnwins=0;
     rootwin->dummy_win=None;
     rootwin->xor_gc=None;
+
+    fp.mode=REGION_FIT_EXACT;
+    fp.g.x=0; fp.g.y=0;
+    fp.g.w=DisplayWidth(dpy, xscr);
+    fp.g.h=DisplayHeight(dpy, xscr);
     
-    geom.x=0; geom.y=0;
-    geom.w=DisplayWidth(dpy, xscr);
-    geom.h=DisplayHeight(dpy, xscr);
-    
-    if(!window_init((WWindow*)rootwin, NULL, root, &geom)){
+    if(!window_do_init((WWindow*)rootwin, NULL, root, &fp)){
         free(rootwin);
         return NULL;
     }
 
-    ((WRegion*)rootwin)->flags|=REGION_BINDINGS_ARE_GRABBED;
+    /* Note: this mask isn't right if some WScreen auses the same window. */
+    ((WWindow*)rootwin)->event_mask=IONCORE_EVENTMASK_ROOT;
+    
+    ((WRegion*)rootwin)->flags|=REGION_BINDINGS_ARE_GRABBED|REGION_PLEASE_WARP;
     ((WRegion*)rootwin)->rootwin=rootwin;
     
-    MARK_REGION_MAPPED(rootwin);
+    REGION_MARK_MAPPED(rootwin);
     
     scan_initial_windows(rootwin);
 
@@ -280,7 +262,7 @@ static WRootWin *preinit_rootwin(int xscr)
     preinit_gr(rootwin);
     netwm_init_rootwin(rootwin);
     
-    region_add_bindmap((WRegion*)rootwin, &ioncore_rootwin_bindmap);
+    region_add_bindmap((WRegion*)rootwin, ioncore_rootwin_bindmap);
     
     return rootwin;
 }
@@ -294,23 +276,27 @@ static WScreen *add_screen(WRootWin *rw, int id, const WRectangle *geom,
 {
     WScreen *scr;
     CARD32 p[1];
+    WFitParams fp;
+    
+    fp.g=*geom;
+    fp.mode=REGION_FIT_EXACT;
     
 #ifdef CF_ALWAYS_VIRTUAL_ROOT
     useroot=FALSE;
 #endif
 
-    scr=create_screen(rw, id, geom, useroot);
+    scr=create_screen(rw, id, &fp, useroot);
     
     if(scr==NULL)
         return NULL;
     
-    region_set_manager((WRegion*)scr, (WRegion*)rw, &(rw->screen_list));
+    region_set_manager((WRegion*)scr, (WRegion*)rw);
     
     region_map((WRegion*)scr);
 
     if(!useroot){
-        p[0]=region_x_window((WRegion*)scr);
-        XChangeProperty(wglobal.dpy, WROOTWIN_ROOT(rw), net_virtual_roots,
+        p[0]=region_xwindow((WRegion*)scr);
+        XChangeProperty(ioncore_g.dpy, WROOTWIN_ROOT(rw), net_virtual_roots,
                         XA_WINDOW, 32, PropModeAppend, (uchar*)&(p[0]), 1);
     }
 
@@ -328,7 +314,8 @@ static bool xinerama_sanity_check(XineramaScreenInfo *xi, int nxi)
             if(i!=j &&
                (xi[j].x_org>=xi[i].x_org && xi[j].x_org<xi[i].x_org+xi[i].width) &&
                (xi[j].y_org>=xi[i].y_org  && xi[j].y_org<xi[i].y_org+xi[i].height)){
-                warn("Xinerama sanity check failed; overlapping screens detected.");
+                warn(TR("Xinerama sanity check failed; overlapping "
+                        "screens detected."));
                 return FALSE;
             }
         }
@@ -339,24 +326,25 @@ static bool xinerama_sanity_check(XineramaScreenInfo *xi, int nxi)
 #endif
 
 
-WRootWin *manage_rootwin(int xscr, bool noxinerama)
+WRootWin *ioncore_manage_rootwin(int xscr, bool noxinerama)
 {
     WRootWin *rootwin;
-    int nxi=0;
+    int nxi=0, fail=0;
 #ifndef CF_NO_XINERAMA
     XineramaScreenInfo *xi=NULL;
     int i;
     int event_base, error_base;
     
     if(!noxinerama){
-        if(XineramaQueryExtension(wglobal.dpy, &event_base, &error_base)){
-            xi=XineramaQueryScreens(wglobal.dpy, &nxi);
+        if(XineramaQueryExtension(ioncore_g.dpy, &event_base, &error_base)){
+            xi=XineramaQueryScreens(ioncore_g.dpy, &nxi);
             
-            if(xi!=NULL && wglobal.rootwins!=NULL){
-                warn("Don't know how to get Xinerama information for "
-                     "multiple X root windows.");
+            if(xi!=NULL && ioncore_g.rootwins!=NULL){
+                warn(TR("Don't know how to get Xinerama information for "
+                        "multiple X root windows."));
                 XFree(xi);
-                return NULL;
+                xi=NULL;
+                nxi=0;
             }
         }
     }
@@ -372,8 +360,8 @@ WRootWin *manage_rootwin(int xscr, bool noxinerama)
         return NULL;
     }
 
-    net_virtual_roots=XInternAtom(wglobal.dpy, "_NET_VIRTUAL_ROOTS", False);
-    XDeleteProperty(wglobal.dpy, WROOTWIN_ROOT(rootwin), net_virtual_roots);
+    net_virtual_roots=XInternAtom(ioncore_g.dpy, "_NET_VIRTUAL_ROOTS", False);
+    XDeleteProperty(ioncore_g.dpy, WROOTWIN_ROOT(rootwin), net_virtual_roots);
 
 #ifndef CF_NO_XINERAMA
     if(xi!=NULL && nxi!=0 && xinerama_sanity_check(xi, nxi)){
@@ -387,31 +375,34 @@ WRootWin *manage_rootwin(int xscr, bool noxinerama)
             geom.h=xi[i].height;
             /*if(nxi==1)
                 useroot=(geom.x==0 && geom.y==0);*/
-            if(!add_screen(rootwin, i, &geom, useroot))
-                warn("Unable to add viewport for Xinerama screen %d", i);
+            if(!add_screen(rootwin, i, &geom, useroot)){
+                warn(TR("Unable to setup Xinerama screen %d."), i);
+                fail++;
+            }
         }
         XFree(xi);
     }else
 #endif
     {
         nxi=1;
-        add_screen(rootwin, xscr, &REGION_GEOM(rootwin), TRUE);
+        if(!add_screen(rootwin, xscr, &REGION_GEOM(rootwin), TRUE))
+            fail++;
     }
     
-    if(rootwin->screen_list==NULL){
-        warn("Unable to add a viewport to X screen %d.", xscr);
-        destroy_obj((WObj*)rootwin);
+    if(fail==nxi){
+        warn(TR("Unable to setup X screen %d."), xscr);
+        destroy_obj((Obj*)rootwin);
         return NULL;
     }
     
     /* */ {
         /* TODO: typed LINK_ITEM */
-        WRegion *tmp=(WRegion*)wglobal.rootwins;
+        WRegion *tmp=(WRegion*)ioncore_g.rootwins;
         LINK_ITEM(tmp, (WRegion*)rootwin, p_next, p_prev);
-        wglobal.rootwins=(WRootWin*)tmp;
+        ioncore_g.rootwins=(WRootWin*)tmp;
     }
 
-    set_cursor(WROOTWIN_ROOT(rootwin), CURSOR_DEFAULT);
+    xwindow_set_cursor(WROOTWIN_ROOT(rootwin), IONCORE_CURSOR_DEFAULT);
     
     return rootwin;
 }
@@ -419,20 +410,22 @@ WRootWin *manage_rootwin(int xscr, bool noxinerama)
 
 void rootwin_deinit(WRootWin *rw)
 {
-    WRegion *reg, *next;
+    WScreen *scr, *next;
 
-    while(rw->screen_list!=NULL)
-        destroy_obj((WObj*)rw->screen_list);
-    
-    /* */ {
-        WRegion *tmp=(WRegion*)wglobal.rootwins;
-        UNLINK_ITEM(tmp, (WRegion*)rw, p_next, p_prev);
-        wglobal.rootwins=(WRootWin*)tmp;
+    FOR_ALL_SCREENS_W_NEXT(scr, next){
+        if(REGION_MANAGER(scr)==(WRegion*)rw)
+            destroy_obj((Obj*)scr);
     }
     
-    XSelectInput(wglobal.dpy, WROOTWIN_ROOT(rw), 0);
+    /* */ {
+        WRegion *tmp=(WRegion*)ioncore_g.rootwins;
+        UNLINK_ITEM(tmp, (WRegion*)rw, p_next, p_prev);
+        ioncore_g.rootwins=(WRootWin*)tmp;
+    }
     
-    XFreeGC(wglobal.dpy, rw->xor_gc);
+    XSelectInput(ioncore_g.dpy, WROOTWIN_ROOT(rw), 0);
+    
+    XFreeGC(ioncore_g.dpy, rw->xor_gc);
     
     window_deinit((WWindow*)rw);
 }
@@ -444,55 +437,52 @@ void rootwin_deinit(WRootWin *rw)
 /*{{{ region dynfun implementations */
 
 
-static void rootwin_set_focus_to(WRootWin *rootwin, bool warp)
+static void rootwin_do_set_focus(WRootWin *rootwin, bool warp)
 {
     WRegion *sub;
     
     sub=REGION_ACTIVE_SUB(rootwin);
     
     if(sub==NULL || !REGION_IS_MAPPED(sub)){
-        FOR_ALL_MANAGED_ON_LIST(rootwin->screen_list, sub){
-            if(REGION_IS_MAPPED(sub))
+        WScreen *scr;
+        FOR_ALL_SCREENS(scr){
+            if(REGION_IS_MAPPED(sub)){
+                sub=(WRegion*)scr;
                 break;
+            }
         }
     }
 
     if(sub!=NULL)
-        region_set_focus_to(sub, warp);
+        region_do_set_focus(sub, warp);
     else
-        SET_FOCUS(WROOTWIN_ROOT(rootwin));
+        window_do_set_focus((WWindow*)rootwin, warp);
 }
 
 
-static void rootwin_fit(WRootWin *rootwin, const WRectangle *geom)
+static bool rootwin_fitrep(WRootWin *rootwin, WWindow *par, 
+                           const WFitParams *fp)
 {
-    warn("Don't know how to rootwin_fit");
+    D(warn("Don't know how to reparent or fit root windows."));
+    return FALSE;
 }
 
 
 static void rootwin_map(WRootWin *rootwin)
 {
-    warn("Attempt to map a root window.");
+    D(warn("Attempt to map a root window."));
 }
 
 
 static void rootwin_unmap(WRootWin *rootwin)
 {
-    warn("Attempt to unmap a root window -- impossible");
+    D(warn("Attempt to unmap a root window -- impossible."));
 }
 
 
-static bool reparent_rootwin(WRootWin *rootwin, WWindow *par, 
-                             const WRectangle *geom)
+static void rootwin_managed_remove(WRootWin *rootwin, WRegion *reg)
 {
-    warn("Attempt to reparent a root window -- impossible");
-    return FALSE;
-}
-
-
-static void rootwin_remove_managed(WRootWin *rootwin, WRegion *reg)
-{
-    region_unset_manager(reg, (WRegion*)rootwin, &(rootwin->screen_list));
+    region_unset_manager(reg, (WRegion*)rootwin);
 }
 
 
@@ -508,114 +498,35 @@ static Window rootwin_x_window(WRootWin *rootwin)
 /*{{{ Misc */
 
 
-/*EXTL_DOC
- * Returns the root window \var{reg}is on.
- */
-EXTL_EXPORT_MEMBER
-WRootWin *region_rootwin_of(const WRegion *reg)
-{
-    WRootWin *rw;
-    assert(reg!=NULL); /* Lua interface should not pass NULL reg. */
-    rw=(WRootWin*)(reg->rootwin);
-    assert(rw!=NULL);
-    return rw;
-}
-
-
-Window region_root_of(const WRegion *reg)
-{
-    return WROOTWIN_ROOT(region_rootwin_of(reg));
-}
-
-
-bool same_rootwin(const WRegion *reg1, const WRegion *reg2)
-{
-    return (reg1->rootwin==reg2->rootwin);
-}
-
-
 static bool scr_ok(WRegion *r)
 {
-    return (WOBJ_IS(r, WScreen) && REGION_IS_MAPPED(r));
+    return (OBJ_IS(r, WScreen) && REGION_IS_MAPPED(r));
 }
 
 
 /*EXTL_DOC
  * Returns previously active screen on root window \var{rootwin}.
  */
+EXTL_SAFE
 EXTL_EXPORT_MEMBER
 WScreen *rootwin_current_scr(WRootWin *rootwin)
 {
     WRegion *r=REGION_ACTIVE_SUB(rootwin);
+    WScreen *scr;
     
     /* There should be no non-WScreen as children or managed by us, but... */
     
     if(r!=NULL && scr_ok(r))
         return (WScreen*)r;
     
-    FOR_ALL_MANAGED_ON_LIST(rootwin->screen_list, r){
-        if(scr_ok(r))
+    FOR_ALL_SCREENS(scr){
+        if(REGION_MANAGER(scr)==(WRegion*)rootwin
+           && REGION_IS_MAPPED(scr)){
             break;
-    }
-    
-    return (WScreen*)r;
-}
-
-
-/*EXTL_DOC
- * Returns a table of root windows indexed by the X screen id.
- */
-EXTL_EXPORT
-ExtlTab root_windows()
-{
-    WRootWin *rootwin;
-    ExtlTab tab=extl_create_table();
-    
-    FOR_ALL_ROOTWINS(rootwin){
-        extl_table_seti_o(tab, rootwin->xscr, (WObj*)rootwin);
-    }
-
-    return tab;
-}
-
-
-WRootWin *find_rootwin_for_root(Window root)
-{
-    WRootWin *rootwin;
-    
-    FOR_ALL_ROOTWINS(rootwin){
-        if(WROOTWIN_ROOT(rootwin)==root)
-            break;
-    }
-    
-    return rootwin;
-}
-
-
-/*}}}*/
-
-
-/*{{{ Workspace and client window management setup */
-
-
-bool setup_rootwins()
-{
-    WRootWin *rootwin;
-    WRegion *reg;
-    int n=0;
-    
-    load_workspaces();
-    
-    FOR_ALL_ROOTWINS(rootwin){
-        FOR_ALL_MANAGED_ON_LIST(rootwin->screen_list, reg){
-            if(WOBJ_IS(reg, WScreen) &&
-               screen_initialize_workspaces((WScreen*)reg))
-                n++;
         }
-        rootwin_manage_initial_windows(rootwin);
     }
     
-    return (n!=0);
+    return scr;
 }
 
 
@@ -626,18 +537,18 @@ bool setup_rootwins()
 
 
 static DynFunTab rootwin_dynfuntab[]={
-    {region_fit, rootwin_fit},
     {region_map, rootwin_map},
     {region_unmap, rootwin_unmap},
-    {region_set_focus_to, rootwin_set_focus_to},
-    {(DynFun*)region_x_window, (DynFun*)rootwin_x_window},
-    {(DynFun*)region_reparent, (DynFun*)reparent_rootwin},
-    {region_remove_managed, rootwin_remove_managed},
+    {region_do_set_focus, rootwin_do_set_focus},
+    {(DynFun*)region_xwindow, (DynFun*)rootwin_x_window},
+    {(DynFun*)region_fitrep, (DynFun*)rootwin_fitrep},
+    {region_managed_remove, rootwin_managed_remove},
     END_DYNFUNTAB
 };
 
 
-IMPLOBJ(WRootWin, WWindow, rootwin_deinit, rootwin_dynfuntab);
+EXTL_EXPORT
+IMPLCLASS(WRootWin, WWindow, rootwin_deinit, rootwin_dynfuntab);
 
     
 /*}}}*/
