@@ -1,7 +1,7 @@
 /*
  * ion/ioncore/screen.h
  *
- * Copyright (c) Tuomo Valkonen 1999-2005. 
+ * Copyright (c) Tuomo Valkonen 1999-2006. 
  *
  * Ion is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by
@@ -30,12 +30,20 @@
         (SCR)!=NULL;                                                   \
         (SCR)=(NXT), NXT=((SCR) ? (SCR)->next_scr : NULL))
 
+enum{
+    SCREEN_ROTATION_0,
+    SCREEN_ROTATION_90,
+    SCREEN_ROTATION_180,
+    SCREEN_ROTATION_270
+};
+
 
 DECLCLASS(WScreen){
     WMPlex mplex;
     int id;
     Atom atom_workspace;
     bool uses_root;
+    int rotation;
     WRectangle managed_off;
     WScreen *next_scr, *prev_scr;
     Watch notifywin_watch;
