@@ -1,7 +1,7 @@
 /*
  * ion/ioncore/selection.h
  *
- * Copyright (c) Tuomo Valkonen 1999-2004. 
+ * Copyright (c) Tuomo Valkonen 1999-2006. 
  *
  * Ion is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by
@@ -14,10 +14,11 @@
 
 #include "common.h"
 
-void send_selection(XSelectionRequestEvent *ev);
-void receive_selection(XSelectionEvent *ev);
-void clear_selection();
-void set_selection(const char *p, int n);
-void request_selection(Window win);
+void ioncore_handle_selection_request(XSelectionRequestEvent *ev);
+void ioncore_handle_selection(XSelectionEvent *ev);
+void ioncore_clear_selection();
+void ioncore_set_selection_n(const char *p, int n);
+void ioncore_set_selection(const char *p);
+void ioncore_request_selection_for(Window win);
 
 #endif /* ION_IONCORE_SELECTION_H */
