@@ -2,7 +2,7 @@
  * Ion dock module
  * Copyright (C) 2003 Tom Payne
  * Copyright (C) 2003 Per Olofsson
- * Copyright (C) 2004-2005 Tuomo Valkonen
+ * Copyright (C) 2004-2006 Tuomo Valkonen
  *
  * by Tom Payne <ion@tompayne.org>
  * based on code by Per Olofsson <pelle@dsv.su.se>
@@ -58,6 +58,9 @@
 #include <ioncore/regbind.h>
 #include <ioncore/extlconv.h>
 #include <ioncore/event.h>
+#include <ioncore/resize.h>
+#include <ioncore/sizehint.h>
+#include <ioncore/basicpholder.h>
 
 #include "exports.h"
 
@@ -367,18 +370,18 @@ static void dock_get_pos_grow(WDock *dock, int *pos, int *grow)
 {
     WMPlex *mplex=OBJ_CAST(REGION_PARENT(dock), WMPlex);
     WRegion *mplex_stdisp;
-    int corner;
+    WMPlexSTDispInfo din;
     
     if(mplex!=NULL){
-        mplex_get_stdisp(mplex, &mplex_stdisp, &corner);
+        mplex_get_stdisp(mplex, &mplex_stdisp, &din);
         if(mplex_stdisp==(WRegion*)dock){
             /* Ok, we're assigned as a status display for mplex, so
              * get parameters from there.
              */
-            *pos=((corner==MPLEX_STDISP_TL || corner==MPLEX_STDISP_BL)
+            *pos=((din.pos==MPLEX_STDISP_TL || din.pos==MPLEX_STDISP_BL)
                   ? DOCK_HPOS_LEFT
                   : DOCK_HPOS_RIGHT) 
-                | ((corner==MPLEX_STDISP_TL || corner==MPLEX_STDISP_TR)
+                | ((din.pos==MPLEX_STDISP_TL || din.pos==MPLEX_STDISP_TR)
                    ? DOCK_VPOS_TOP
                    : DOCK_VPOS_BOTTOM);
             *grow=dock->grow;
@@ -635,6 +638,41 @@ static void calc_dock_pos(WRectangle *dg, const WRectangle *pg, int pos)
     }
 }
 
+    
+static void dock_set_minmax(WDock *dock, int grow, const WRectangle *g)
+{
+    dock->min_w=g->w;
+    dock->min_h=g->h;
+    if(grow==DOCK_GROW_UP || grow==DOCK_GROW_DOWN){
+        dock->max_w=g->w;
+        dock->max_h=INT_MAX;
+    }else{
+        dock->max_w=INT_MAX;
+        dock->max_h=g->h;
+    }
+}
+
+
+static void dockapp_calc_preferred_size(WDock *dock, int grow, 
+                                        const WRectangle *tile_size,
+                                        WDockApp *da)
+{
+    XSizeHints hints;
+    int w=da->geom.w, h=da->geom.h;
+    
+    if(grow==DOCK_GROW_UP || grow==DOCK_GROW_DOWN){
+        da->geom.w=minof(w, tile_size->w);
+        da->geom.h=h;
+    }else{
+        da->geom.w=w;
+        da->geom.h=minof(h, tile_size->h);
+    }
+    
+    region_size_hints(da->reg, &hints);
+    xsizehints_correct(&hints, &(da->geom.w), &(da->geom.h), TRUE);
+}
+
+
 
 static void dock_managed_rqgeom_(WDock *dock, WRegion *reg, int flags,
                                  const WRectangle *geom, WRectangle *geomret,
@@ -704,6 +742,9 @@ static void dock_managed_rqgeom_(WDock *dock, WRegion *reg, int flags,
         }
         
         if(update){
+            /* Calculcate preferred size */
+            dockapp_calc_preferred_size(dock, grow, &tile_size, da);
+                        
             /* Determine whether dockapp should be placed on a tile */
             da->tile=da->geom.w<=tile_size.w && da->geom.h<=tile_size.h;
             
@@ -715,7 +756,7 @@ static void dock_managed_rqgeom_(WDock *dock, WRegion *reg, int flags,
                 da->tile_geom.w=da->geom.w;
                 da->tile_geom.h=da->geom.h;
             }
-            
+
             /* Calculate border width and height */
             da->border_geom.w=dockapp_bdw.left+da->tile_geom.w+dockapp_bdw.right;
             da->border_geom.h=dockapp_bdw.top+da->tile_geom.h+dockapp_bdw.right;
@@ -751,13 +792,14 @@ static void dock_managed_rqgeom_(WDock *dock, WRegion *reg, int flags,
             break;
         case DOCK_GROW_UP:
         case DOCK_GROW_DOWN:
+        default:
             dock_geom.w=max_w;
             dock_geom.h=total_h;
             break;
         }
     }else{
-        dock_geom.w=1;
-        dock_geom.h=1;
+        dock_geom.w=tile_size.w;
+        dock_geom.h=tile_size.h;
     }
     border_dock_geom.w=dock_bdw.left+dock_geom.w+dock_bdw.right;
     border_dock_geom.h=dock_bdw.top+dock_geom.h+dock_bdw.bottom;
@@ -767,31 +809,25 @@ static void dock_managed_rqgeom_(WDock *dock, WRegion *reg, int flags,
     /* Fit dock to new geom if required */
     if(!(flags&REGION_RQGEOM_TRYONLY)){
         int rqgeomflags=REGION_RQGEOM_WEAK_X|REGION_RQGEOM_WEAK_Y;
-        WRectangle *g=&border_dock_geom;
-        dock->min_w=g->w;
-        dock->min_h=g->h;
-        if(grow==DOCK_GROW_UP || grow==DOCK_GROW_DOWN){
-            dock->max_w=g->w;
-            dock->max_h=INT_MAX;
-        }else{
-            dock->max_w=INT_MAX;
-            dock->max_h=g->h;
-        }
+        
+        dock_set_minmax(dock, grow, &border_dock_geom);
         
         if(just_update_minmax)
             return;
         
         dock->arrange_called=FALSE;
-        region_rqgeom((WRegion*)dock, rqgeomflags, g, NULL);
+        region_rqgeom((WRegion*)dock, rqgeomflags, &border_dock_geom, NULL);
         if(!dock->arrange_called)
             dock_arrange_dockapps(dock, &REGION_GEOM(dock), NULL, NULL);
-        if(geomret!=NULL)
+        
+        if(thisdockapp!=NULL && geomret!=NULL)
             *geomret=thisdockapp->geom;
     }else{
-        dock_arrange_dockapps(dock, &border_dock_geom, thisdockapp,
-                              &thisdockapp_copy);
-        if(geomret!=NULL)
+        if(thisdockapp!=NULL && geomret!=NULL){
+            dock_arrange_dockapps(dock, &REGION_GEOM(dock), 
+                                  thisdockapp, &thisdockapp_copy);
             *geomret=thisdockapp_copy.geom;
+        }
     }
 }
 
@@ -823,7 +859,7 @@ static bool dock_fitrep(WDock *dock, WWindow *parent, const WFitParams *fp)
 {
     WFitParams fp2;
     
-    if(fp->mode==REGION_FIT_BOUNDS){
+    if(fp->mode&REGION_FIT_BOUNDS){
         int pos, grow;
         dock_get_pos_grow(dock, &pos, &grow);
         fp2.mode=REGION_FIT_EXACT;
@@ -1001,18 +1037,19 @@ static void dock_do_set(WDock *dock, ExtlTab conftab, bool resize)
     if(resize && (growset || posset)){
         WMPlex *par=OBJ_CAST(REGION_PARENT(dock), WMPlex);
         WRegion *stdisp=NULL;
-        int pos;
+        WMPlexSTDispInfo din;
         
         if(par!=NULL){
-            mplex_get_stdisp(par, &stdisp, &pos);
+            mplex_get_stdisp(par, &stdisp, &din);
+            din.fullsize=FALSE; /* not supported. */
             if(stdisp==(WRegion*)dock){
                 if(posset)
-                    mplexpos(dock->pos, &pos);
+                    mplexpos(dock->pos, &din.pos);
                 if(growset){
                     /* Update min/max first */
                     dock_managed_rqgeom_(dock, NULL, 0, NULL, NULL, TRUE);
                 }
-                mplex_set_stdisp(par, (WRegion*)dock, pos);
+                mplex_set_stdisp(par, (WRegion*)dock, &din);
             }
         }
         
@@ -1109,7 +1146,7 @@ static bool dock_init(WDock *dock, WWindow *parent, const WFitParams *fp)
     /* Just calculate real min/max size */
     dock_managed_rqgeom_(dock, NULL, 0, NULL, NULL, TRUE);
     
-    if(fp->mode==REGION_FIT_BOUNDS){
+    if(fp->mode&REGION_FIT_BOUNDS){
         WRectangle dg;
         dg.w=minof(dock->min_w, fp->g.w);
         dg.h=minof(dock->min_h, fp->g.h);
@@ -1163,7 +1200,7 @@ WDock *mod_dock_create(ExtlTab tab)
     WDock *dock=NULL;
     WFitParams fp;
     WRegion *stdisp=NULL;
-    int pos=0;
+    WMPlexSTDispInfo din;
     
     if(extl_table_gets_s(tab, "mode", &mode)){
         if(strcmp(mode, "floating")==0){
@@ -1192,7 +1229,7 @@ WDock *mod_dock_create(ExtlTab tab)
     }
 
     if(!floating){
-        mplex_get_stdisp((WMPlex*)screen, &stdisp, &pos);
+        mplex_get_stdisp((WMPlex*)screen, &stdisp, &din);
         if(stdisp!=NULL && !extl_table_is_bool_set(tab, "force")){
             warn("Screen %d already has an stdisp. Refusing to add embedded "
                  "dock.", screenid);
@@ -1223,8 +1260,9 @@ WDock *mod_dock_create(ExtlTab tab)
         if(mplex_attach_simple((WMPlex*)screen, (WRegion*)dock, af)!=NULL)
             return dock;
     }else{
-        mplexpos(dock->pos, &pos);
-        if(mplex_set_stdisp((WMPlex*)screen, (WRegion*)dock, pos))
+        mplexpos(dock->pos, &din.pos);
+        din.fullsize=FALSE; /* not supported */
+        if(mplex_set_stdisp((WMPlex*)screen, (WRegion*)dock, &din))
             return dock;
     }
     
@@ -1297,34 +1335,43 @@ WRegion *dock_load(WWindow *par, const WFitParams *fp, ExtlTab tab)
 /*{{{ Client window management setup */
 
 
-static WDockApp *do_insert_dockapp(WDock *dock, WRegion *reg, 
-                                   bool draw_border,
-                                   int pos)
+static WDockApp *dock_do_attach_(WDock *dock, 
+                                 WRegionAttachHandler *handler,
+                                 void *handlerparams)
 {
     WDockApp *dockapp, *before_dockapp;
-    WRectangle geom;
-    
+    WFitParams fp;
+    WRegion *reg;
+    bool draw_border=TRUE;
+    int pos=INT_MAX;
+     
     /* Create and initialise a new WDockApp struct */
     dockapp=ALLOC(WDockApp);
     
     if(dockapp==NULL)
         return NULL;
+    
+    dock_get_tile_size(dock, &(fp.g));
+    fp.g.x=0;
+    fp.g.y=0;
+    fp.mode=REGION_FIT_WHATEVER|REGION_FIT_BOUNDS;
 
-    geom.x=0;
-    geom.y=0;
-    geom.w=REGION_GEOM(reg).w;
-    geom.h=REGION_GEOM(reg).h;
-
-    if(!region_reparent(reg, (WWindow*)dock, &geom, REGION_FIT_BOUNDS)){
+    reg=handler((WWindow*)dock, &fp, handlerparams);
+    
+    if(reg==NULL){
         free(dockapp);
         return NULL;
     }
 
-    region_detach_manager(reg);
-    
+    if(OBJ_IS(reg, WClientWin)){
+        ExtlTab proptab=((WClientWin*)reg)->proptab;
+        extl_table_gets_b(proptab, CLIENTWIN_WINPROP_BORDER, &draw_border);
+        extl_table_gets_i(proptab, CLIENTWIN_WINPROP_POSITION, &pos);
+    }
+
     dockapp->reg=reg;
-    dockapp->draw_border=draw_border; /*TRUE*/
-    dockapp->pos=pos; /*INT_MAX*/
+    dockapp->draw_border=draw_border;
+    dockapp->pos=pos;
     dockapp->tile=FALSE;
 
     /* Insert the dockapp at the correct relative position */
@@ -1342,9 +1389,10 @@ static WDockApp *do_insert_dockapp(WDock *dock, WRegion *reg,
 
     region_set_manager(reg, (WRegion*)dock);
     
+    fp.g=REGION_GEOM(reg);
     dock_managed_rqgeom(dock, reg, 
                         REGION_RQGEOM_WEAK_X|REGION_RQGEOM_WEAK_Y,
-                        &geom, NULL);
+                        &(fp.g), NULL);
     
     region_map(reg);
 
@@ -1352,21 +1400,62 @@ static WDockApp *do_insert_dockapp(WDock *dock, WRegion *reg,
 }
 
 
-static bool dock_manage_clientwin(WDock *dock, WClientWin *cwin,
-                                  const WManageParams *param UNUSED,
-                                  int redir)
+static WRegion *dock_do_attach_simple(WDock *dock,
+                                      WRegionAttachHandler *handler,
+                                      void *handlerparams)
 {
-    WRectangle geom;
-    bool draw_border=TRUE;
-    int pos=INT_MAX;
+    WDockApp *da=dock_do_attach_(dock, handler, handlerparams);
+    return (da!=NULL ? da->reg : NULL);
+}
 
+
+static WRegion *dock_do_attach(WDock *dock,
+                               WRegionAttachHandler *handler,
+                               void *handlerparams,
+                               void *param UNUSED)
+{
+    return dock_do_attach_simple(dock, handler, handlerparams);
+}
+
+
+/*EXTL_DOC
+ * Attach \var{reg} to \var{dock}.
+ */
+EXTL_EXPORT_MEMBER
+bool dock_attach(WDock *dock, WRegion *reg)
+{
+    return (region__attach_reparent((WRegion*)dock, reg,
+                                    (WRegionDoAttachFn*)dock_do_attach, 
+                                    NULL)
+            !=NULL);
+}
+
+
+static bool dock_handle_drop(WDock *dock, int x, int y,
+                             WRegion *dropped)
+{
+    return dock_attach(dock, dropped);
+}
+
+
+static WBasicPHolder *dock_managed_get_pholder(WDock *dock, WRegion *mgd)
+{
+    return create_basicpholder((WRegion*)dock, 
+                               ((WRegionDoAttachFnSimple*)
+                                dock_do_attach_simple));
+}
+
+
+static WPHolder *dock_prepare_manage(WDock *dock, const WClientWin *cwin,
+                                     const WManageParams *param UNUSED,
+                                     int redir)
+{
     if(redir==MANAGE_REDIR_STRICT_YES)
-        return FALSE;
+        return NULL;
     
-    extl_table_gets_b(cwin->proptab, CLIENTWIN_WINPROP_BORDER, &draw_border);
-    extl_table_gets_i(cwin->proptab, CLIENTWIN_WINPROP_POSITION, &pos);
-    
-    return (do_insert_dockapp(dock, (WRegion*)cwin, draw_border, pos)!=NULL);
+    return (WPHolder*)create_basicpholder((WRegion*)dock, 
+                                          ((WRegionDoAttachFnSimple*)
+                                           dock_do_attach_simple));
 }
 
 
@@ -1509,22 +1598,6 @@ static bool clientwin_do_manage_hook(WClientWin *cwin, const WManageParams *para
                                    MANAGE_REDIR_PREFER_NO);
 }
 
-/*}}}*/
-
-
-/*{{{ Drop */
-
-
-static bool dock_handle_drop(WDock *dock, int x, int y,
-                             WRegion *dropped)
-{
-#ifdef CF_EXPERIMENTAL_DOCK_DROP
-    return (do_insert_dockapp(dock, dropped, FALSE, INT_MAX)!=NULL);
-#else
-    return FALSE;
-#endif
-}
-
 
 /*}}}*/
 
@@ -1604,7 +1677,7 @@ static DynFunTab dock_dynfuntab[]={
     {window_draw, dock_draw},
     {region_updategr, dock_updategr},
     {region_managed_rqgeom, dock_managed_rqgeom},
-    {(DynFun*)region_manage_clientwin, (DynFun*)dock_manage_clientwin},
+    {(DynFun*)region_prepare_manage, (DynFun*)dock_prepare_manage},
     {region_managed_remove, dock_managed_remove},
     {(DynFun*)region_get_configuration, (DynFun*)dock_get_configuration},
     {region_size_hints, dock_size_hints},
@@ -1613,6 +1686,9 @@ static DynFunTab dock_dynfuntab[]={
     {(DynFun*)region_may_destroy, (DynFun*)dock_may_destroy},
     {(DynFun*)region_handle_drop, (DynFun*)dock_handle_drop},
     {(DynFun*)region_rqgeom_clientwin, (DynFun*)dock_rqgeom_clientwin},
+
+    {(DynFun*)region_managed_get_pholder,
+     (DynFun*)dock_managed_get_pholder},
     END_DYNFUNTAB
 };
 
