@@ -1,7 +1,7 @@
 /*
  * ion/mod_ionws/ionws.c
  *
- * Copyright (c) Tuomo Valkonen 1999-2005. 
+ * Copyright (c) Tuomo Valkonen 1999-2006. 
  *
  * Ion is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by
@@ -101,7 +101,7 @@ static void reparent_mgd(WRegion *sub, WWindow *par)
 bool ionws_fitrep(WIonWS *ws, WWindow *par, const WFitParams *fp)
 {
     WIonWSIterTmp tmp;
-    bool rs;
+    bool ok=FALSE;
     
     if(par!=NULL){
         if(!region_same_rootwin((WRegion*)ws, (WRegion*)par))
@@ -115,8 +115,13 @@ bool ionws_fitrep(WIonWS *ws, WWindow *par, const WFitParams *fp)
     
     REGION_GEOM(ws)=fp->g;
     
-    if(ws->split_tree!=NULL)
-        split_resize(ws->split_tree, &(fp->g), PRIMN_ANY, PRIMN_ANY);
+    if(ws->split_tree!=NULL){
+        bool done=FALSE;
+        if(fp->mode&REGION_FIT_ROTATE)
+            ok=split_rotate_to(ws->split_tree, &(fp->g), fp->rotation);
+        if(!ok)
+            split_resize(ws->split_tree, &(fp->g), PRIMN_ANY, PRIMN_ANY);
+    }
     
     return TRUE;
 }
@@ -211,10 +216,8 @@ bool ionws_managed_goto(WIonWS *ws, WRegion *reg, int flags)
         }
     }
 
-    if(flags&REGION_GOTO_FOCUS){
-        ioncore_set_previous_of(reg);
+    if(flags&REGION_GOTO_FOCUS)
         region_maybewarp(reg, !(flags&REGION_GOTO_NOWARP));
-    }
 
     return TRUE;
 }
@@ -296,7 +299,8 @@ void ionws_unmanage_stdisp(WIonWS *ws, bool permanent, bool nofocus)
 
 
 static void ionws_create_stdispnode(WIonWS *ws, WRegion *stdisp, 
-                                    int corner, int orientation)
+                                    int corner, int orientation, 
+                                    bool fullsize)
 {
     int flags=REGION_RQGEOM_WEAK_X|REGION_RQGEOM_WEAK_Y;
     WRectangle *wg=&REGION_GEOM(ws), dg;
@@ -330,6 +334,7 @@ static void ionws_create_stdispnode(WIonWS *ws, WRegion *stdisp,
     
     stdispnode->corner=corner;
     stdispnode->orientation=orientation;
+    stdispnode->fullsize=fullsize;
     
     split=create_splitsplit(wg, (orientation==REGION_ORIENTATION_HORIZONTAL 
                                  ? SPLIT_VERTICAL
@@ -353,9 +358,11 @@ static void ionws_create_stdispnode(WIonWS *ws, WRegion *stdisp,
         (corner==MPLEX_STDISP_TR || corner==MPLEX_STDISP_BR))){
         split->tl=ws->split_tree;
         split->br=(WSplit*)stdispnode;
+        split->current=SPLIT_CURRENT_TL;
     }else{
         split->tl=(WSplit*)stdispnode;
         split->br=ws->split_tree;
+        split->current=SPLIT_CURRENT_BR;
     }
 
     ws->split_tree=(WSplit*)split;
@@ -364,7 +371,8 @@ static void ionws_create_stdispnode(WIonWS *ws, WRegion *stdisp,
 }
 
 
-void ionws_manage_stdisp(WIonWS *ws, WRegion *stdisp, int corner)
+void ionws_manage_stdisp(WIonWS *ws, WRegion *stdisp, 
+                         const WMPlexSTDispInfo *di)
 {
     bool mcf=region_may_control_focus((WRegion*)ws);
     int flags=REGION_RQGEOM_WEAK_X|REGION_RQGEOM_WEAK_Y;
@@ -382,13 +390,14 @@ void ionws_manage_stdisp(WIonWS *ws, WRegion *stdisp, int corner)
 
     /* Remove old stdisp if corner and orientation don't match.
      */
-    if(ws->stdispnode!=NULL && (corner!=ws->stdispnode->corner ||
+    if(ws->stdispnode!=NULL && (di->pos!=ws->stdispnode->corner ||
                                 orientation!=ws->stdispnode->orientation)){
         ionws_unmanage_stdisp(ws, TRUE, TRUE);
     }
 
     if(ws->stdispnode==NULL){
-        ionws_create_stdispnode(ws, stdisp, corner, orientation);
+        ionws_create_stdispnode(ws, stdisp, di->pos, orientation, 
+                                di->fullsize);
         if(ws->stdispnode==NULL)
             return;
     }else{
@@ -400,6 +409,7 @@ void ionws_manage_stdisp(WIonWS *ws, WRegion *stdisp, int corner)
             assert(ws->stdispnode->regnode.reg==NULL);
         }
         
+        ws->stdispnode->fullsize=di->fullsize;
         ws->stdispnode->regnode.reg=stdisp;
         splittree_set_node_of(stdisp, &(ws->stdispnode->regnode));
     }
@@ -411,10 +421,8 @@ void ionws_manage_stdisp(WIonWS *ws, WRegion *stdisp, int corner)
     
     dg=((WSplit*)(ws->stdispnode))->geom;
     
-    if(orientation==REGION_ORIENTATION_HORIZONTAL)
-        dg.h=maxof(CF_STDISP_MIN_SZ, region_min_h(stdisp));
-    else
-        dg.w=maxof(CF_STDISP_MIN_SZ, region_min_w(stdisp));
+    dg.h=stdisp_recommended_h(ws->stdispnode);
+    dg.w=stdisp_recommended_w(ws->stdispnode);
     
     splittree_rqgeom((WSplit*)(ws->stdispnode), flags, &dg, FALSE);
     
@@ -548,7 +556,9 @@ void ionws_deinit(WIonWS *ws)
 {
     WRegion *reg;
     WIonWSIterTmp tmp;
-    
+
+    ionws_unmanage_stdisp(ws, FALSE, TRUE);
+
     FOR_ALL_MANAGED_BY_IONWS(reg, ws, tmp){
         destroy_obj((Obj*)reg);
     }
@@ -557,8 +567,6 @@ void ionws_deinit(WIonWS *ws)
         assert(FALSE);
     }
     
-    ionws_unmanage_stdisp(ws, TRUE, TRUE);
-
     if(ws->split_tree!=NULL)
         destroy_obj((Obj*)(ws->split_tree));
 
@@ -1223,7 +1231,7 @@ bool iowns_transpose_at(WIonWS *ws, WRegion *reg)
 /*}}}*/
 
 
-/*{{{Floating toggle */
+/*{{{ Floating toggle */
 
 
 static void replace(WSplitSplit *split, WSplitSplit *nsplit)
@@ -1607,7 +1615,7 @@ WRegion *ionws_load(WWindow *par, const WFitParams *fp, ExtlTab tab)
 /*}}}*/
 
 
-/*{{{Dynamic function table and class implementation */
+/*{{{ Dynamic function table and class implementation */
 
 
 static DynFunTab ionws_dynfuntab[]={
@@ -1632,8 +1640,8 @@ static DynFunTab ionws_dynfuntab[]={
     {(DynFun*)region_managed_goto,
      (DynFun*)ionws_managed_goto},
     
-    {(DynFun*)region_manage_clientwin, 
-     (DynFun*)ionws_manage_clientwin},
+    {(DynFun*)region_prepare_manage, 
+     (DynFun*)ionws_prepare_manage},
     
     {(DynFun*)region_rescue_clientwins,
      (DynFun*)ionws_rescue_clientwins},
