@@ -1,7 +1,7 @@
 /*
  * ion/mod_ionws/placement.h
  *
- * Copyright (c) Tuomo Valkonen 1999-2005. 
+ * Copyright (c) Tuomo Valkonen 1999-2006. 
  *
  * Ion is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by
@@ -32,8 +32,7 @@ typedef struct{
  */
 extern WHook *ionws_placement_alt;
 
-extern bool ionws_manage_clientwin(WIonWS *ws, WClientWin *cwin,
-                                   const WManageParams *param,
-                                   int redir);
+extern WPHolder *ionws_prepare_manage(WIonWS *ws, const WClientWin *cwin,
+                                      const WManageParams *param, int redir);
 
 #endif /* ION_MOD_IONWS_PLACEMENT_H */
