@@ -1,7 +1,7 @@
 /*
  * ion/mod_panews/placement.h
  *
- * Copyright (c) Tuomo Valkonen 1999-2005. 
+ * Copyright (c) Tuomo Valkonen 1999-2006. 
  *
  * Ion is free software; you can redistribute it and/or modify it under
  * the terms of the GNU Lesser General Public License as published by
@@ -46,9 +46,9 @@ extern WHook *panews_init_layout_alt;
 extern WHook *panews_make_placement_alt;
 
 
-extern bool panews_manage_clientwin(WPaneWS *ws, WClientWin *cwin,
-                                    const WManageParams *param,
-                                    int redir);
+extern WPHolder *panews_prepare_manage(WPaneWS *ws, const WClientWin *cwin,
+                                       const WManageParams *param,
+                                       int redir);
 extern bool panews_handle_unused_drop(WPaneWS *ws, WSplitUnused *specifier, 
                                       WRegion *reg);
 
